@@ -28,9 +28,11 @@
 #include <extractor.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <libgen.h>
 
 #include "libfossrepo.h"
 #include "libfossdb.h"
+#include "libfossagent.h"
 
 #ifdef SVN_REV
 char BuildVersion[]="Build version: " SVN_REV ".\n";
@@ -195,17 +197,6 @@ KeyType KeywordTypes[] = {
 
 #define MAXCMD	65536
 
-/**************************************************
- ShowHeartbeat(): Given an alarm signal, display a
- heartbeat.
- **************************************************/
-void    ShowHeartbeat   (int Sig)
-{
-  printf("Heartbeat\n");
-  fflush(stdout);
-  /* re-schedule itself */
-  alarm(60);
-} /* ShowHeartbeat() */
 
 /*********************************************************
  GetKey(): Given a libextractor index, return the index
@@ -352,7 +343,7 @@ void	PrintKeys	(EXTRACTOR_KeywordList *keywords)
 	/* NOTE: Postgres does not have an "UPDATE OR INSERT" function,
 	   so there is a race condition for duplicates. */
         memset(SQL,'\0',sizeof(SQL));
-        snprintf(SQL,sizeof(SQL),"INSERT INTO attrib (attrib_key_fk,attrib_value,pfile_fk) VALUES ('%d',E'%s',E'%s');",
+        snprintf(SQL,sizeof(SQL),"INSERT INTO attrib (attrib_key_fk,attrib_value,pfile_fk) VALUES ('%d',E'%s','%s');",
 	  KeywordTypes[K].DBIndex,
 	  TaintString(keywords->keyword),
 	  Akey);
@@ -365,37 +356,6 @@ void	PrintKeys	(EXTRACTOR_KeywordList *keywords)
     } /* for() */
 } /* PrintKeys() */
 
-/**********************************************
- ReadLine(): Read a command from stdin.
- If the line is empty, then try again.
- Returns line length, or -1 of EOF.
- **********************************************/
-int     ReadLine (FILE *Fin, char *Line, int MaxLine)
-{
-  int C;
-  int i;
-
-  memset(Line,'\0',MaxLine);
-  if (feof(Fin)) return(-1);
-  i=0;
-  C=fgetc(Fin);
-  if (C<0) return(-1);
-  while(!feof(Fin) && (C>=0) && (i<MaxLine))
-    {
-    if (C=='\n')
-        {
-        if (i > 0) return(i);
-        /* if it is a blank line, then ignore it. */
-        }
-    else
-        {
-        Line[i]=C;
-        i++;
-        }
-    C=fgetc(Fin);
-    }
-  return(i);
-} /* ReadLine() */
 
 /**********************************************
  GetFieldValue(): Given a string that contains
@@ -508,44 +468,6 @@ void    SetEnv  (char *S, int Env)
   if (GotTable) { Table = getenv("ARG_table"); }
 } /* SetEnv() */
 
-/*********************************************************
- GetAgentKey(): Get the Agent Key from the database.
- *********************************************************/
-void	GetAgentKey	()
-{
-  int rc;
-
-  rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='pkgmetagetta' ORDER BY agent_id DESC;");
-  if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'pkgmetagetta' from the database table 'agent'\n");
-	DBclose(DB);
-	exit(-1);
-	}
-  if (DBdatasize(DB) <= 0)
-      {
-      /* Not found? Add it! */
-      rc = DBaccess(DB,"INSERT INTO agent (agent_name,agent_rev,agent_desc) VALUES ('pkgmetagetta','unknown','Load attributes with meta data from pfile');");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to write to the database\n");
-	printf("LOG: unable to write 'pkgmetagetta' to the database table 'agent'\n");
-	DBclose(DB);
-	exit(-1);
-	}
-      rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='pkgmetagetta' ORDER BY agent_id DESC;");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'pkgmetagetta' from the database table 'agent'\n");
-	DBclose(DB);
-	exit(-1);
-	}
-      }
-  Agent_pk = atoi(DBgetvalue(DB,0,0));
-} /* GetAgentKey() */
-
 /*********************************************************
  Usage():
  *********************************************************/
@@ -570,6 +492,7 @@ int	main	(int argc, char *argv[])
   char *Path;
   char *Env;
   int rc;
+  char *agent_desc = "Use libextractor to retrieve general file metadata";
 
   /* Init extractor */
   extractors = EXTRACTOR_loadDefaultLibraries();
@@ -591,7 +514,7 @@ int	main	(int argc, char *argv[])
 			printf("FATAL: Unable to connect to database\n");
 			exit(-1);
 			}
-		GetAgentKey();
+		Agent_pk = GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
 		/* insert EVERY meta type */
 		for(c=0; KeywordTypes[c].Label; c++)
 			GetKey(KeywordTypes[c].KeyIndex);
@@ -646,7 +569,7 @@ int	main	(int argc, char *argv[])
 	printf("FATAL: Unable to connect to database\n");
 	exit(-1);
 	}
-    GetAgentKey();
+    Agent_pk = GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
 
     signal(SIGALRM,ShowHeartbeat);
     alarm(60);
@@ -700,7 +623,7 @@ int	main	(int argc, char *argv[])
 		}
 	    /* Mark it as processed */
 	    memset(SQL,0,sizeof(SQL));
-	    snprintf(SQL,sizeof(SQL),"INSERT INTO attrib (attrib_key_fk,attrib_value,pfile_fk) VALUES ('%d','true',E'%s');",KeywordTypes[GetKey(-2)].DBIndex,getenv("ARG_akey"));
+	    snprintf(SQL,sizeof(SQL),"INSERT INTO attrib (attrib_key_fk,attrib_value,pfile_fk) VALUES ('%d','true','%s');",KeywordTypes[GetKey(-2)].DBIndex,getenv("ARG_akey"));
 	    DBaccess(DB,SQL);
 	    /* Make the table as processed */
 	    /** Without this, we need a "SELECT ... EXCEPT SELECT..." which
