@@ -26,9 +26,12 @@
 #include <dirent.h>
 #include <time.h>
 #include <signal.h>
+#include <libgen.h>
 
 #include <libfossdb.h>
 #include <libfossrepo.h>
+#include "libfossagent.h"
+
 
 #ifdef SVN_REV
 char BuildVersion[]="Build version: " SVN_REV ".\n";
@@ -47,25 +50,6 @@ char	SQL[MAXSQL];
 /* For heartbeats */
 long	ItemsProcessed=0;
 
-/**************************************************
- ShowHeartbeat(): Given an alarm signal, display a
- heartbeat.
- **************************************************/
-void    ShowHeartbeat   (int Sig)
-{
-  if (ItemsProcessed > 0)
-    {
-    printf("ItemsProcessed %ld\n",ItemsProcessed);
-    ItemsProcessed=0;
-    }
-  else
-    {
-    printf("Heartbeat\n");
-    }
-  fflush(stdout);
-  /* re-schedule itself */
-  alarm(60);
-} /* ShowHeartbeat() */
 
 /*********************************************
  MyDBaccess(): DBaccess with debugging.
@@ -119,10 +103,6 @@ void	DeleteLicense	(long UploadId)
       snprintf(SQL,sizeof(SQL),"DELETE FROM licterm_name WHERE pfile_fk IN (SELECT pfile_fk FROM uploadtree WHERE upload_fk = '%ld');",UploadId);
       MyDBaccess(DB,SQL);
 
-      memset(SQL,'\0',sizeof(SQL));
-      snprintf(SQL,sizeof(SQL),"UPDATE pfile SET pfile_liccount = NULL FROM uploadtree WHERE upload_fk = '%ld' AND pfile_pk = pfile_fk AND pfile_liccount IS NOT NULL;",UploadId);
-      MyDBaccess(DB,SQL);
-
       memset(SQL,'\0',sizeof(SQL));
       snprintf(SQL,sizeof(SQL),"DELETE FROM agent_lic_status WHERE pfile_fk IN (SELECT pfile_fk FROM uploadtree WHERE upload_fk = '%ld');",UploadId);
       MyDBaccess(DB,SQL);
@@ -131,6 +111,7 @@ void	DeleteLicense	(long UploadId)
       snprintf(SQL,sizeof(SQL),"DELETE FROM agent_lic_meta WHERE pfile_fk IN (SELECT pfile_fk FROM uploadtree WHERE upload_fk = '%ld');",UploadId);
       MyDBaccess(DB,SQL);
   ItemsProcessed+=DBdatasize(VDB);
+  Heartbeat(ItemsProcessed);
 
   /***********************************************/
   /* Commit the change! */
@@ -203,7 +184,7 @@ void	DeleteUpload	(long UploadId)
   /** These are all pfiles in the upload_fk that only appear once. **/
   memset(SQL,'\0',sizeof(SQL));
   if (Verbose) { printf("# Getting list of pfiles to delete\n"); }
-  snprintf(SQL,sizeof(SQL),"SELECT DISTINCT pfile_pk,pfile_sha1 || '.' || pfile_md5 || '.' || pfile_size AS pfile,0 AS count INTO %s_pfile FROM uploadtree INNER JOIN pfile ON upload_fk = %ld AND pfile_fk = pfile_pk;",TempTable,UploadId);
+  snprintf(SQL,sizeof(SQL),"SELECT DISTINCT pfile_pk,pfile_sha1 || '.' || pfile_md5 || '.' || pfile_size AS pfile INTO %s_pfile FROM uploadtree INNER JOIN pfile ON upload_fk = %ld AND pfile_fk = pfile_pk;",TempTable,UploadId);
   MyDBaccess(DB,SQL);
 
   /* Remove pfiles with reuse */
@@ -230,24 +211,12 @@ void	DeleteUpload	(long UploadId)
    ***********************************************/
 
   /***********************************************/
-  /* Blow away uploadtree */
-  memset(SQL,'\0',sizeof(SQL));
-  if (Verbose) { printf("# Deleting uploadtree\n"); }
-  snprintf(SQL,sizeof(SQL),"DELETE FROM uploadtree WHERE upload_fk = %ld;",UploadId);
-  MyDBaccess(DB,SQL);
-
-  /***********************************************/
-  /* delete pfiles that are missing reuse in the DB */
+  /* delete pfile references from all the pfile dependent tables */
   if (Verbose) { printf("# Deleting from licterm_name\n"); }
   memset(SQL,'\0',sizeof(SQL));
   snprintf(SQL,sizeof(SQL),"DELETE FROM licterm_name USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
   MyDBaccess(DB,SQL);
 
-  if (Verbose) { printf("# Removing license counts\n"); }
-  memset(SQL,'\0',sizeof(SQL));
-  snprintf(SQL,sizeof(SQL),"UPDATE pfile SET pfile_liccount = NULL FROM %s_pfile WHERE %s_pfile.pfile_pk = pfile.pfile_pk;",TempTable,TempTable);
-  MyDBaccess(DB,SQL);
-
   if (Verbose) { printf("# Deleting from agent_lic_status\n"); }
   memset(SQL,'\0',sizeof(SQL));
   snprintf(SQL,sizeof(SQL),"DELETE FROM agent_lic_status USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
@@ -263,10 +232,66 @@ void	DeleteUpload	(long UploadId)
   snprintf(SQL,sizeof(SQL),"DELETE FROM attrib USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
   MyDBaccess(DB,SQL);
 
+  /* delete package info table */
+  if (Verbose) { printf("# Deleting pkg_deb_req\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM pkg_deb_req USING pkg_deb,%s_pfile WHERE pkg_fk = pkg_pk AND pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
+  if (Verbose) { printf("# Deleting pkg_deb\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM pkg_deb USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
+  if (Verbose) { printf("# Deleting pkg_rpm_req\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM pkg_rpm_req USING pkg_rpm,%s_pfile WHERE pkg_fk = pkg_pk AND pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
+  if (Verbose) { printf("# Deleting pkg_rpm\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM pkg_rpm USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
+  /* delete pfiles in the license_file table */
+  if (Verbose) { printf("# Deleting from licese_file\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM license_file USING %s_pfile "
+	   "WHERE pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
   /***********************************************/
   /*** Everything above is slow, everything below is fast ***/
   /***********************************************/
 
+  /* Delete upload from nomos_ars */
+  memset(SQL,'\0',sizeof(SQL));
+  if (Verbose) { printf("# Deleting nomos_ars\n"); }
+  snprintf(SQL,sizeof(SQL),"DELETE FROM nomos_ars WHERE upload_fk = %ld;",UploadId);
+  MyDBaccess(DB,SQL);
+
+  /* Delete upload reference from bucket_ars */
+  memset(SQL,'\0',sizeof(SQL));
+  if (Verbose) { printf("# Deleting bucket_ars\n"); }
+  snprintf(SQL,sizeof(SQL),"DELETE FROM bucket_ars WHERE upload_fk = %ld;",UploadId);
+  MyDBaccess(DB,SQL);
+  /* Delete uploadtree reference from bucket_container  */
+  memset(SQL,'\0',sizeof(SQL));
+  if (Verbose) { printf("# Deleting bucket_container\n"); }
+  snprintf(SQL,sizeof(SQL),"DELETE FROM bucket_container USING uploadtree WHERE uploadtree_fk = uploadtree_pk AND upload_fk = %ld;",UploadId);
+  MyDBaccess(DB,SQL);
+  /* Delete pfile reference from bucket_file */
+  if (Verbose) { printf("# Deleting bucket_file\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM bucket_file USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
+  /* Delete pfile reference from copyright table */
+  if (Verbose) { printf("# Deleting copyright\n"); }
+  memset(SQL,'\0',sizeof(SQL));
+  snprintf(SQL,sizeof(SQL),"DELETE FROM copyright USING %s_pfile WHERE pfile_fk = pfile_pk;",TempTable);
+  MyDBaccess(DB,SQL);
+
   /***********************************************/
   /* Blow away jobs */
   /*****
@@ -373,6 +398,7 @@ void	DeleteUpload	(long UploadId)
 	else RepRemove("gold",S);
 	}
       ItemsProcessed++;
+      Heartbeat(ItemsProcessed);
       }
     } /* if Test <= 1 */
   DBclose(VDB);
@@ -571,13 +597,13 @@ void	DeleteFolder	(long FolderId)
 /**********************************************************************/
 
 /**********************************************
- ReadLine(): Read a single line from a file.
+ ReadFileLine(): Read a single line from a file.
  Used to read from stdin.
  Process line elements.
  Returns: 1 of read data, 0=no data, -1=EOF.
  NOTE: It only returns 1 if a filename changes!
  **********************************************/
-int     ReadLine        (FILE *Fin)
+int     ReadFileLine        (FILE *Fin)
 {
   int C='@';
   int i=0;      /* index */
@@ -664,48 +690,8 @@ int     ReadLine        (FILE *Fin)
     }
 
   return(rc);
-} /* ReadLine() */
+} /* ReadFileLine() */
 
-/*********************************************************
- GetAgentKey(): Get the Agent Key from the database.
- *********************************************************/
-void	GetAgentKey	()
-{
-  int rc;
-
-  rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='delagent' ORDER BY agent_id DESC;");
-  if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'delagent' from the database table 'agent'\n");
-	fflush(stdout);
-	DBclose(DB);
-	exit(-1);
-	}
-  if (DBdatasize(DB) <= 0)
-      {
-      /* Not found? Add it! */
-      rc = DBaccess(DB,"INSERT INTO agent (agent_name,agent_rev,agent_desc) VALUES ('delagent','unknown','Remove uploads and folders');");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to write to the database\n");
-	printf("LOG: unable to write 'delagent' to the database table 'agent'\n");
-	fflush(stdout);
-	DBclose(DB);
-	exit(-1);
-	}
-      rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='delagent' ORDER BY agent_id DESC;");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'delagent' from the database table 'agent'\n");
-	fflush(stdout);
-	DBclose(DB);
-	exit(-1);
-	}
-      }
-  Agent_pk = atoi(DBgetvalue(DB,0,0));
-} /* GetAgentKey() */
 
 /**********************************************************************/
 /**********************************************************************/
@@ -741,6 +727,7 @@ int	main	(int argc, char *argv[])
   long DelUpload=0, DelFolder=0, DelLicense=0;
   int Scheduler=0; /* should it run from the scheduler? */
   int GotArg=0;
+  char *agent_desc = "Deletes upload.  Other list/delete options available from the command line.";
 
   while((c = getopt(argc,argv,"ifF:lL:sTuU:v")) != -1)
     {
@@ -753,7 +740,7 @@ int	main	(int argc, char *argv[])
 	  fprintf(stderr,"ERROR: Unable to open DB\n");
 	  exit(-1);
 	  }
-	GetAgentKey();
+	GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
 	DBclose(DB);
 	return(0);
       case 'f': ListFolder=1; GotArg=1; break;
@@ -781,7 +768,7 @@ int	main	(int argc, char *argv[])
 	fprintf(stderr,"ERROR: Unable to open DB\n");
 	exit(-1);
 	}
-  GetAgentKey();
+  GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
   signal(SIGALRM,ShowHeartbeat);
 
   if (ListProj) ListUploads();
@@ -795,7 +782,7 @@ int	main	(int argc, char *argv[])
   /* process from the scheduler */
   if (Scheduler)
     {
-    while(ReadLine(stdin) >= 0) ;
+    while(ReadFileLine(stdin) >= 0) ;
     }
 
   DBclose(DB);
