@@ -30,9 +30,11 @@
 #include <fcntl.h>
 #include <sys/resource.h>  /* for rlimit */
 #include <time.h> /* for time() used when debugging performance */
+#include <libgen.h>
 
 #include "libfossrepo.h"
 #include "libfossdb.h"
+#include "libfossagent.h"
 
 #ifdef SVN_REV
 char BuildVersion[]="Build version: " SVN_REV ".\n";
@@ -94,30 +96,6 @@ int	DebugDBaccess	(void *a, char *b)
   return(rc);
 } /* DebugDBaccess() */
 
-long    HeartbeatValue=-1;
-long	LastHeartbeatValue=-1;
-
-/**************************************************
- ShowHeartbeat(): Given an alarm signal, display a
- heartbeat.
- **************************************************/
-void    ShowHeartbeat   (int Sig)
-{
-
-  /* IF we are tracking hearbeat values AND it has not changed,
-     THEN don't display a heartbeat message.
-     This can happen if I/O is hung, but alarms are still being processed.
-   */
-  if ((HeartbeatValue == -1) || (HeartbeatValue != LastHeartbeatValue))
-    {
-    LastHeartbeatValue = HeartbeatValue;
-    printf("Heartbeat\n");
-    fflush(stdout);
-    }
-
-  /* re-schedule itself */
-  alarm(60);
-} /* ShowHeartbeat() */
 
 /************************************************************/
 /************************************************************/
@@ -231,12 +209,12 @@ char *	GetFieldValue	(char *Sin, char *Field, int FieldMax,
 } /* GetFieldValue() */
 
 /**********************************************
- ReadLine(): Read a single line from a file.
+ ReadFileLine(): Read a single line from a file.
  Used to read from stdin.
  Process line elements.
  Returns: 1 of read data, 0=no data, -1=EOF.
  **********************************************/
-int	ReadLine	(FILE *Fin)
+int	ReadFileLine	(FILE *Fin)
 {
   int C='@';
   int i=0;	/* index */
@@ -250,7 +228,6 @@ int	ReadLine	(FILE *Fin)
   /* inform scheduler that we're ready for data */
   printf("OK\n");
   alarm(60);
-  HeartbeatValue = -1;
   fflush(stdout);
 
   if (feof(Fin))
@@ -289,7 +266,7 @@ int	ReadLine	(FILE *Fin)
     if (!strcasecmp(Field,"A")) { strncpy(PfileName,Value,sizeof(PfileName)); rc |= 2; }
     }
   return(rc==3);
-} /* ReadLine() */
+} /* ReadFileLine() */
 
 /************************************************************/
 /************************************************************/
@@ -990,53 +967,6 @@ void	ProcessTerms	()
       }
 } /* ProcessTerms() */
 
-/*********************************************************
- GetAgentKey(): Get the Agent Key from the database.
- TBD: When this engine is used for other things, we will need
- a switch statement for the different types of agents.
- *********************************************************/
-void	GetAgentKey	()
-{
-  int rc;
-
-  /* Order in descenting order, so longest strings come first. */
-  rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='licinspect' ORDER BY agent_id DESC;");
-  if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'licinspect' from the database table 'agent'\n");
-	fflush(stdout);
-	DBclose(DB);
-	exit(1);
-	}
-  if (DBdatasize(DB) <= 0)
-      {
-      /* Not found? Add it! */
-      rc = DBaccess(DB,"INSERT INTO agent (agent_name,agent_rev,agent_desc) VALUES ('licinspect','unknown','Analyze files for licenses');");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to write to the database\n");
-	printf("LOG: unable to write 'licinspect' to the database table 'agent'\n");
-	fflush(stdout);
-	DBclose(DB);
-	exit(1);
-	}
-#if 0
-      /** Disabled: Database will take care of this **/
-      DBaccess(DB,"ANALYZE agent;");
-#endif
-      rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='licinspect' ORDER BY agent_id DESC;");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'licinspect' from the database table 'agent'\n");
-	fflush(stdout);
-	DBclose(DB);
-	exit(-1);
-	}
-      }
-  Agent_pk = atoi(DBgetvalue(DB,0,0));
-} /* GetAgentKey() */
 
 /**********************************************
  Usage(): Display program usage.
@@ -1095,6 +1025,7 @@ int	main	(int argc, char *argv[])
   char *Needle=NULL;
   char *Haystack=NULL;
   int MustStoreDB=0;
+  char *agent_desc = "Looks for short license strings";
 
   while((c = getopt(argc,argv,"DiH:M:N:S:s:tvX")) != -1)
     {
@@ -1108,7 +1039,7 @@ int	main	(int argc, char *argv[])
 	  fprintf(stderr,"FATAL: Unable to open DB\n");
 	  exit(-1);
 	  }
-	GetAgentKey();
+	GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
 	DBclose(DB);
 	return(0);
       case 'H':	Haystack = optarg; break;
@@ -1235,7 +1166,7 @@ int	main	(int argc, char *argv[])
     {
     /* processing from the scheduler */
     StoreDB=1;
-    rc = ReadLine(stdin);
+    rc = ReadFileLine(stdin);
     do
       {
       if (rc > 0)
@@ -1286,7 +1217,7 @@ int	main	(int argc, char *argv[])
 	}
 
       /* Off to the next item to process */
-      rc = ReadLine(stdin);
+      rc = ReadFileLine(stdin);
       } while(rc >= 0);
     } /* if reading from the scheduler */
 
