@@ -1,6 +1,6 @@
 /***************************************************************
  Copyright (C) 2006-2009 Hewlett-Packard Development Company, L.P.
- 
+
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.
@@ -14,7 +14,21 @@
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-***************************************************************/
+ ***************************************************************/
+
+/* Equivalent to core nomos v1.10 */
+
+/**
+ * \file list.c
+ * \brief list manipulation functions and str/val Compare functions
+ *
+ * list.c supplies all of the functions needed to manipulate the list and
+ * listitem strunctures defined in nomos.h.  It also supplies the
+ * str*Compare* and valCompare* functions.
+ *
+ * @version "$Id: list.c 2657 2009-11-25 23:24:40Z bobgo $"
+ *
+ */
 
 #include "nomos.h"
 #include "list.h"
@@ -35,19 +49,26 @@ static void listValidate(list_t *, int);
 static void listDebugDetails();
 #endif	/* PROC_TRACE || LIST_DEBUG */
 
-void listInit(list_t *l, int size, char *label)
-{
-/* */
+/**
+ * \brief intialize a list, if the list is not empty, empty it (initialize it to
+ * zero's).
+ *
+ * sets:\n
+        l->name to label\n
+        l->size to DFL_STARTSIZE\n
+ 	    l->used = 0\n
+	    l->ix = -1\n
+	    l->sorted = UNSORTED\n
+
+ * NOTE: label can't be longer than l->name (64)
+ *
+ */
+void listInit(list_t *l, int size, char *label) {
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listInit(%p, %d, \"%s\")\n", l, size, label);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
+	traceFunc("== listInit(%p, %d, \"%s\")\n", l, size, label);
 #endif	/* PROC_TRACE */
-/* */
+
 	if (l == NULL_LIST) {
 		Fatal("listInit: List @ %p is NULL", l);
 	}
@@ -57,26 +78,26 @@ void listInit(list_t *l, int size, char *label)
 	if (strlen(label) > sizeof(l->name)) {
 		Fatal("List name \"%s\" too long", label);
 	}
-	(void) strcpy(l->name, label);
+  if (l->name != label) (void) strcpy(l->name, label);
 	if (size == 0) {
 #ifdef	LIST_DEBUG
 		printf("LIST: (%p) initialize %s to %d elements\n", l,
-		    l->name, DFL_STARTSIZE);
+				l->name, DFL_STARTSIZE);
 #endif	/* LIST_DEBUG */
-		l->size = DFL_STARTSIZE;	/* default start */
+		l->size = DFL_STARTSIZE; /* default start */
 		l->items = (item_t *)memAlloc(l->size*(int)sizeof(item_t),
-		    l->name);
+				l->name);
 	}
 #ifdef	QA_CHECKS
 	else if (size != l->size) {
 		Assert(NO, "%s: specified reset size %d != list size %d",
-		    l->name, size, l->size);
+				l->name, size, l->size);
 	}
 #endif	/* QA_CHECKS */
 	else {
 #ifdef	LIST_DEBUG
 		printf("LIST: reset %d elements in \"%s\" (%d bytes)\n",
-		    l->size, l->name, l->size*sizeof(item_t));
+				l->size, l->name, l->size*sizeof(item_t));
 #endif	/* LIST_DEBUG */
 		memset(l->items, 0, l->size*sizeof(item_t));
 	}
@@ -86,54 +107,52 @@ void listInit(list_t *l, int size, char *label)
 	return;
 }
 
-void listClear(list_t *l, int deallocFlag)
-{
-	register item_t *p;
-	register int i;
-/* */
+void listClear(list_t *l, int deallocFlag) {
+	item_t *p;
+	int i;
+
 #if defined(PROC_TRACE) /* || defined(UNPACK_DEBUG) */
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listClear(%p, %s)\n", l,
-	    deallocFlag ? "DEALLOC" : "NOTOUCH");
+	traceFunc("== listClear(%p, %s)\n", l,
+			deallocFlag ? "DEALLOC" : "NOTOUCH");
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE || UNPACK_DEBUG */
-/* */
+
 	if (l == NULL_LIST) {
 #ifdef	LIST_DEBUG
 		printf("%% clear NULL list\n");
 #endif	/* LIST_DEBUG */
 		return;
 	}
+
 	if (l->size == 0) {
 #ifdef	LIST_DEBUG
 		printf("%% clear empty list \"%s\"\n", l->name);
 #endif	/* LIST_DEBUG */
 		return;
 	}
+#ifdef LIST_DEBUG
+	listDump(l, YES)
+#endif /* LIST_DEBUG */
+
 #ifdef	GLOBAL_DEBUG
 	if (gl.MEM_DEEBUG) {
 		printf("... used %d size %d ix %d sorted %d items %p\n",
-		    l->used, l->size, l->ix, l->sorted, l->items);
+				l->used, l->size, l->ix, l->sorted, l->items);
 	}
 #endif	/* GLOBAL_DEBUG */
 	if (l->used) {
 		if (l->items == NULL_ITEM) {
 			Assert(NO, "%s: used/size %d/%d with null data",
-			    l->name, l->used, l->size);
+			l->name, l->used, l->size);
 		}
 #ifdef	LIST_DEBUG
 		printf("LIST: clearing %s, used entries == %d\n", l->name,
-		    l->used);
+				l->used);
 #endif	/* LIST_DEBUG */
 #ifdef	GLOBAL_DEBUG
 		if (gl.MEM_DEEBUG) {
 			printf("LIST: clearing %s, used entries == %d\n",
-			    l->name, l->used);
+					l->name, l->used);
 		}
 #endif	/* GLOBAL_DEBUG */
 		for (p = l->items, i = 0; i < l->used; i++, p++) {
@@ -141,7 +160,7 @@ void listClear(list_t *l, int deallocFlag)
 #ifdef	GLOBAL_DEBUG
 				if (gl.MEM_DEEBUG) {
 					printf("FREE %p items[%d].str %p\n",
-					    l, i, p->str);
+							l, i, p->str);
 				}
 #endif	/* GLOBAL_DEBUG */
 				memFree((void *) p->str, MTAG_LISTKEY);
@@ -151,7 +170,7 @@ void listClear(list_t *l, int deallocFlag)
 #ifdef	GLOBAL_DEBUG
 				if (gl.MEM_DEEBUG) {
 					printf("... FREE %p items[%d].buf %p\n",
-					    l, i, p->buf);
+							l, i, p->buf);
 				}
 #endif	/* GLOBAL_DEBUG */
 				memFree((void *) p->buf, MTAG_LISTBUF);
@@ -184,16 +203,15 @@ void listClear(list_t *l, int deallocFlag)
 	return;
 }
 
-void listValidate(list_t *l, int appendFlag)
-{
+void listValidate(list_t *l, int appendFlag) {
 	if (l == NULL_LIST) {
 		Fatal("listValidate: null list!");
 	}
-/*
- * Question: do we want to initialize the list here, instead of aborting?
- * It would mean we don't have to initialize EVERY list EVERYWHERE -- we
- * could just set the size to zero and start adding/inserting.
- */
+	/*
+	 * Question: do we want to initialize the list here, instead of aborting?
+	 * It would mean we don't have to initialize EVERY list EVERYWHERE -- we
+	 * could just set the size to zero and start adding/inserting.
+	 */
 	if (l->size == 0) {
 		Fatal("List (%s) @ %p not initialized", l->name, l);
 	}
@@ -208,69 +226,80 @@ void listValidate(list_t *l, int appendFlag)
 	return;
 }
 
-item_t *listGetItem(list_t *l, char *s)
-{
-	register item_t *p;
-	register int i, x;
-	item_t *newptr;
-	size_t sz;
-/* */
+
+/**
+ * listGetItem
+ * \brief get an item from the itemlist.  If the item is not in the itemlist,
+ * then add it to the itemlist.
+ *
+ * This function searches the str member in the listitem structure, if found,
+ * a pointer to that item is returned.  If not found, the item is added to the
+ * list of items 'in the middle' of the list.
+ *
+ * @param list_t *list the list to search/update
+ * @param *s pointer to the string to search for.
+ *
+ * @return pointer to the item
+ */
+item_t *listGetItem(list_t *l, char *s) {
+	item_t *p;
+	int i;
+	int x;
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listGetItem(%p, \"%s\")\n", l, s);
+	traceFunc("== listGetItem(%p, \"%s\")\n", l, s);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
-	listValidate(l, YES);	/* assume/setup for an 'add' */
+
+	listValidate(l, YES); /* assume/setup for an 'add' */
 	if (s == NULL_STR) {
 		Assert(NO, "listGetItem: Null string to insert!");
 	}
 	if (l->sorted && l->sorted != SORT_BY_NAME) {
-		Fatal("%s is sorted other than by-name (%d)", l->name,
-		    l->sorted);
+		Fatal("%s is sorted other than by-name (%d)", l->name, l->sorted);
 	}
 	else if (l->used == 0) {
 		l->sorted = SORT_BY_NAME;
 	}
-/*
- * Now we KNOW we have at least one opening in the list; see if the
- * requested string already exists in the list
- */
+	/*
+	 * Now we KNOW we have at least one opening in the list; see if the
+	 * requested string already exists in the list
+	 */
+	/**
+	 \todo CDB -- Change so that there is only one loop variable in the
+	 for loop
+	 */
 	for (p = l->items, i = 0; i < l->used; i++, p++) {
 #ifdef	LIST_DEBUG
-		printf("%p: i = %d, used = %d, size = %d\n", l, i, l->size,
-		    l->size);
+		printf("%p: check i = %d, used = %d, size = %d\n", l, i, l->used,
+				l->size);
 #endif	/* LIST_DEBUG */
 		if ((x = strcmp(s, p->str)) == 0) {
-			return(p);
+			return (p);
 		}
-		else if (x < 0) {	/* e.g., not in list */
-			break;		/* add new list entry */
+		else if (x < 0) { /* e.g., not in list */
+			break; /* add new list entry */
 		}
-	}
+	} /* for */
 #ifdef	LIST_DEBUG
 	printf("listGetItem: new entry @%d (size %d, max %d)\n", i,
-	    l->used, l->size);
+			l->used, l->size);
 #endif	/* LIST_DEBUG */
-	if (i != l->used) {	/* make room in 'middle' of list */
-		(void) memmove(l->items+i+1, l->items+i,
-		    (l->used-i)*sizeof(*p));
+	if (i != l->used) { /* make room in 'middle' of list */
+		(void) memmove(l->items+i+1, l->items+i, (l->used-i)*sizeof(*p));
 	}
 	(l->used)++;
 	p->str = copyString(s, MTAG_SORTKEY);
 	p->buf = NULL_STR;
-	p->val = p->val2 = p->val3 = 0;
+	p->val = 0;
+	p->val2 = 0;
+	p->val3 = 0;
 #ifdef	LIST_DEBUG
 	printf("ADDING: insert %s @%d, \"used\" now == %d, Cache (listDump):\n",
-	    p->str, i, l->used);
+			p->str, i, l->used);
 	listDump(l, NO);
 #endif	/* LIST_DEBUG */
-	return(p);
+	return (p);
 }
 
 /*
@@ -279,37 +308,31 @@ item_t *listGetItem(list_t *l, char *s)
  * end of the unpacking process - this just appends an entry at the
  * bottom/end of the list.
  */
-item_t *listAppend(list_t *l, char *s)
-{
-	register item_t *p;	/* computed return value */
-/* */
+item_t *listAppend(list_t *l, char *s) {
+	item_t *p; /* computed return value */
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listAppend(%p, \"%s\")\n", l, s);
+	traceFunc("== listAppend(%p, \"%s\")\n", l, s);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
+
 	listValidate(l, YES);
 	if (s == NULL_STR) {
 		Assert(NO, "listAppend: Null string to insert!");
 	}
-/*
- * Now we know we have a valid list with enough room to add one more
- * element; simply insert it at the end, increment the 'used' counter
- * and get outta Dodge.
- */
+	/*
+	 * Now we know we have a valid list with enough room to add one more
+	 * element; simply insert it at the end, increment the 'used' counter
+	 * and get outta Dodge.
+	 */
 	p = &l->items[l->used++];
- 	p->str = copyString(s, MTAG_UNSORTKEY);
+	p->str = copyString(s, MTAG_UNSORTKEY);
 	p->buf = NULL_STR;
 	p->val = p->val2 = p->val3 = 0;
-	return(p);
+	return (p);
 }
 
+#ifdef notdef
 /*
  * Look up an element in a list based on it's name (str) value and
  * return NULL if not found.
@@ -320,21 +343,27 @@ item_t *listAppend(list_t *l, char *s)
  * the name of a DOS-format package on-the-fly.  This function should
  * probably be used sparingly -- as little as needed, actually. :(
  */
+/*
+ CDB -- From comment above, we could probably get rid of this. #ifdef'd
+ out for now.
+ */
 item_t *listLookupName(list_t *l, char *s)
 {
-	register item_t *p;	/* computed return value */
-	register int i, x;
+	item_t *p; /* computed return value */
+	int i;
+	int match;
+
 #if defined(PROC_TRACE)
 #ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
+	if (gl.ptswitch) {
 #endif	/* PROC_TRACE_SWITCH */
-	printf("== listLookupName(%p, \"%s\")\n", l, s);
-	listDebugDetails(l);
+		printf("== listLookupName(%p, \"%s\")\n", l, s);
+		listDebugDetails(l);
 #ifdef	PROC_TRACE_SWITCH
-    }
+	}
 #endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
+
 #if	defined(QA_CHECKS) || defined(LIST_DEBUG)
 	listValidate(l, NO);
 	if (s == NULL_STR) {
@@ -342,36 +371,38 @@ item_t *listLookupName(list_t *l, char *s)
 		return(NULL_ITEM);
 	}
 #endif	/* QA_CHECKS || LIST_DEBUG */
-/*
- * Now we know we have a valid list with enough room to add one more
- * element; simply insert it at the end, increment the 'used' counter
- * and get outta Dodge.
- */
+	/*
+	 * Now we know we have a valid list with enough room to add one more
+	 * element; simply insert it at the end, increment the 'used' counter
+	 * and get outta Dodge.
+	 */
 	if (l->sorted != SORT_BY_NAME && l->sorted != 0) {
 		Fatal("Improper sort-type %d for %s name-lookup",
-		    l->sorted, l->name);
+				l->sorted, l->name);
 	}
-/*
- * Walk through the sorted-by-name list and exit when we're done.
- * This function could be called during a loop (while(listIterate(&list)))
- * and we DON'T want to mess up the 'ix' field for this list!
- */
-	for (i = 0, p = l->items; i < l->used; i++, p++) {
-		if (p->str == NULL_STR) {
+	/*
+	 * Walk through the sorted-by-name list and exit when we're done.
+	 * This function could be called during a loop (while(listIterate(&list)))
+	 * and we DON'T want to mess up the 'ix' field for this list!
+	 */
+	for (i = 0; i < l->used; i++) {
+		if (l->items[i].str == NULL_STR) {
 			Assert(NO, "%s[%d] is NULL!", l->name, i);
 			continue;
 		}
-/*printf("DEBUG: strcmp(\"%s\", \"%s\")\n", s, p->str);*/
-		if ((x = strcmp(s, p->str)) == 0) {
-			return(p);
+		match = strcmp(s, l->items[i].str);
+		if (match == 0) {
+			return(&(l->items[i]));
 		}
-		else if (x < 0) {	/* e.g., cannnot be in list */
+		else if (match < 0) { /* e.g., cannnot be in list */
 			break;
 		}
 	}
 	return(NULL_ITEM);
 }
+#endif /* notdef */
 
+#ifdef notdef
 /*
  * Look up an element in a list based on it's alias (buf) value and
  * return NULL if not found.
@@ -383,39 +414,39 @@ item_t *listLookupName(list_t *l, char *s)
  */
 item_t *listLookupAlias(list_t *l, char *s)
 {
-	register item_t *p;	/* computed return value */
-	register int i, x;
-/* */
+	item_t *p; /* computed return value */
+	int i;
+	int x;
+
 #if defined(PROC_TRACE)
 #ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
+	if (gl.ptswitch) {
 #endif	/* PROC_TRACE_SWITCH */
-	printf("== listLookupAlias(%p, \"%s\")\n", l, s);
-	listDebugDetails(l);
+		printf("== listLookupAlias(%p, \"%s\")\n", l, s);
+		listDebugDetails(l);
 #ifdef	PROC_TRACE_SWITCH
-    }
+	}
 #endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
 #if	defined(QA_CHECKS) || defined(LIST_DEBUG)
 	listValidate(l, NO);
 	if (s == NULL_STR) {
 		Assert(NO, "lookupAlias: Null key for lookup!");
 	}
 #endif	/* QA_CHECKS || LIST_DEBUG */
-/*
- * Now we know we have a valid list with enough room to add one more
- * element; simply insert it at the end, increment the 'used' counter
- * and get outta Dodge.
- */
+	/*
+	 * Now we know we have a valid list with enough room to add one more
+	 * element; simply insert it at the end, increment the 'used' counter
+	 * and get outta Dodge.
+	 */
 	if (l->sorted != SORT_BY_ALIAS) {
 		Fatal("Improper sort-type %d for %s alias-lookup",
-		    l->sorted, l->name);
+				l->sorted, l->name);
 	}
-/*
- * Walk through the sorted-by-alias list and exit when we're done.
- * Do NOT use listIterate() or we could mess up the 'ix' field!
- */
+	/*
+	 * Walk through the sorted-by-alias list and exit when we're done.
+	 * Do NOT use listIterate() or we could mess up the 'ix' field!
+	 */
 	for (i = 0, p = l->items; i < l->used; i++, p++) {
 		if (p->buf == NULL_STR) {
 			Assert(NO, "%s[%d] is NULL!", l->name, i);
@@ -424,273 +455,249 @@ item_t *listLookupAlias(list_t *l, char *s)
 		if ((x = strcmp(s, p->buf)) == 0) {
 			return(p);
 		}
-		else if (x < 0) {	/* e.g., not in list */
+		else if (x < 0) { /* e.g., not in list */
 			break;
 		}
 	}
 	return(NULL_ITEM);
 }
+#endif /* notdef */
+
+/**
+ * listIterate
+ * \brief return a pointer to listitem, returns a NULL_ITEM when no more items
+ * to return.
+ *
+ * @param list_t *list a point to a list
+ *
+ * NOTE: this routine increments the ix member! (bad boy)
+ *
+ * \todo remove/fix the fact that this routine increments ix.
+ */
+item_t *listIterate(list_t *l) {
+
+	item_t *p;
 
-item_t *listIterate(list_t *l)
-{
-	register item_t *p;
-/* */
 #ifdef	LIST_DEBUG /* was PROC_TRACE */
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listIterate(%p) -- %s (ix %d, used %d)\n", l, l->name,
-	    l->ix, l->used);
+	traceFunc("== listIterate(%p) -- %s (ix %d, used %d)\n", l, l->name,
+			l->ix, l->used);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* LIST_DEBUG, oh-so-formerly-PROC_TRACE */
-/* */
+
 #if	defined(QA_CHECKS) || defined(LIST_DEBUG)
 	listValidate(l, NO);
-	if (l->used == 0) {	/* empty list? */
+	if (l->used == 0) { /* empty list? */
 		return(NULL_ITEM);
 	}
 #endif	/* QA_CHECKS || LIST_DEBUG */
 	l->ix++;
-/*
- * Remember: an array in 'C' of size 5 uses indices [0..4]
- */
+
 	if (l->ix == l->used) {
 #ifdef	LIST_DEBUG
 		Assert(NO, "End-of-list: %s", l->name);
 #endif	/* LIST_DEBUG */
 		l->ix = -1;
-		return(NULL_ITEM);
-	}
-	else if (l->ix > l->used || l->ix < 0) {
-		Fatal("Index %d out of bounds (%d) on %s", l->ix, l->used,
-		    l->name);
+		return (NULL_ITEM);
+	} else if ((l->ix > l->used) || (l->ix < 0)) {
+		Fatal("Index %d out of bounds (%d) on %s", l->ix, l->used, l->name);
 	}
 	p = l->items+(l->ix);
-	return(p);
+	return (p);
 }
 
-void listIterationReset(list_t *l)
-{
-	register item_t *p;
-/* */
+void listIterationReset(list_t *l) {
+
 #ifdef	LIST_DEBUG /* was PROC_TRACE */
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listIterationReset(%p) -- %s (ix %d, used %d)\n", l, l->name,
-	    l->ix, l->used);
+	traceFunc("== listIterationReset(%p) -- %s (ix %d, used %d)\n", l, l->name,
+			l->ix, l->used);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* LIST_DEBUG, oh-so-formerly-PROC_TRACE */
-/* */
+
 #if	defined(QA_CHECKS) || defined(LIST_DEBUG)
 	listValidate(l, NO);
 #endif	/* QA_CHECKS || LIST_DEBUG */
-	l->ix = -1;		/* reset index for listIterate() */
+
+	l->ix = -1; /* reset index for listIterate() */
 	return;
 }
 
-int listDelete(list_t *l, item_t *p)
-{
-	register int index;
-	register item_t *base;
-/* */
+int listDelete(list_t *l, item_t *p) {
+	int index;
+	item_t *base;
+
 #if defined(PROC_TRACE)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listDelete(%p, %p)\n", l, p);
+	traceFunc("== listDelete(%p, %p)\n", l, p);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
+
 #if	defined(QA_CHECKS) || defined(LIST_DEBUG)
 	listValidate(l, NO);
 #endif	/* QA_CHECKS || LIST_DEBUG */
 	if ((base = l->items) == NULL_ITEM) {
 		Assert(NO, "%s: empty list", l->name);
-		return(0);
+		return (0);
 	}
 	if ((index = p-base) >= l->used) {
 		Assert(NO, "%s[%d] is out of range", l->name, p-(l->items));
-		return(0);
+		return (0);
 	}
 #ifdef	LIST_DEBUG
 	printf("DEBUG: listDelete: delete index %d (used %d, size %d)\n",
-	    index, l->used, l->size);
+			index, l->used, l->size);
 #endif	/* LIST_DEBUG */
-/*
- * If anything was allocated, delete it.
- */
- 	if (p->str != NULL_STR) {
+	/*
+	 * If anything was allocated, delete it.
+	 */
+	if (p->str != NULL_STR) {
 		memFree(p->str, MTAG_LISTKEY);
 	}
- 	if (p->buf != NULL_STR) {
+	if (p->buf != NULL_STR) {
 		memFree(p->buf, MTAG_LISTBUF);
 	}
-/*
- * move everything up (e.g., from index+1 to index, index+2 to index+1)
- */
+	/*
+	 * move everything up (e.g., from index+1 to index, index+2 to index+1)
+	 */
 	if (index+1 < l->used) {
-		(void) memmove(l->items+index, l->items+index+1,
-		    (size_t)((l->used-index)*sizeof(item_t)));
+		(void) memmove(l->items+index, l->items+index+1, (size_t)((l->used
+				-index)*sizeof(item_t)));
 	}
-	l->used--;		/* ... then just ignore it now */
-	return(1);
+	l->used--; /* ... then just ignore it now */
+	return (1);
 }
 
-static void listDoubleSize(list_t *l)
-{
-	register int sz;
+static void listDoubleSize(list_t *l) {
+	int sz;
 	item_t *newptr;
-/* */
+
 #if defined(PROC_TRACE)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listDoubleSize(%p) -- %s\n", l, l->name);
+	traceFunc("== listDoubleSize(%p) -- %s\n", l, l->name);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
+
 	sz = (size_t) (l->used * (int)sizeof(item_t));
 #ifdef	LIST_DEBUG
 	printf("LIST: %s FULL (%d) @ addr %p! -- %d -> %d\n", l->name,
-	    l->used, l, sz, sz*2);
+			l->used, l, sz, sz * 2);
 #endif	/* LIST_DEBUG */
-#if	0
-	if ((newptr = realloc((void *)l->items, sz*2)) == (void *) NULL) {
-		perror("realloc");
-		fprintf(stderr, "Can't realloc list\n");
-		Bail(1);
-	}
-	memset((void *) (newptr + sz), 0, sz);	/* set to zero */
-#endif
 #ifdef	MEMSTATS
-	printf("... DOUBLE \"%s\" (%d -> %d) => %d slots\n", l->name, sz, sz*2,
-	    sz*2/sizeof(item_t));
-#if	0
-	memStats("before list-double");
-#endif
+	printf("... DOUBLE \"%s\" (%d -> %d) => %d slots\n", l->name, sz, sz * 2,
+			(sz * 2)/sizeof(item_t));
 #endif	/* MEMSTATS */
-	newptr = (item_t *)memAlloc((int) sz*2, MTAG_DOUBLED);
+
+	newptr = (item_t *)memAlloc(sz * 2, MTAG_DOUBLED);
 	memcpy((void *) newptr, (void *) l->items, sz);
 	if (l->items != newptr) {
 #ifdef	LIST_DEBUG
 		printf("LIST: old %p new %p\n", l->items, newptr);
 #endif	/* LIST_DEBUG */
 		memFree(l->items, MTAG_TOOSMALL);
-		l->items = (item_t *) newptr;
+		l->items = newptr;
 	}
 	l->size *= 2;
-#if	0
-#ifdef	MEMSTATS
-	memStats("after list-double");
-#endif	/* MEMSTATS */
-#endif
 	return;
 }
 
-void listSort(list_t *l, int sortType)
-{
-	int (*f)();
-/* */
+void listSort(list_t *l, int sortType) {
+
+	int (*f)() = 0;
+
 #ifdef	PROC_TRACE
 	char *fName;
 #ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
+	if (gl.ptswitch) {
 #endif	/* PROC_TRACE_SWITCH */
-	printf("== listSort(%p, %d", l, sortType);
-	switch (sortType) {
-		case SORT_BY_NAME: printf("(NAME)"); break;
-		case SORT_BY_COUNT_DSC: printf("(COUNT_DSC)"); break;
-		case SORT_BY_COUNT_ASC: printf("(COUNT_ASC)"); break;
-		case SORT_BY_ALIAS: printf("(ALIAS)"); break;
-		case SORT_BY_BASENAME: printf("(BASENAME)"); break;
-		default: printf("(***)"); break;
-	}
-	printf(")\n");
-	listDebugDetails(l);
+		printf("== listSort(%p, %d", l, sortType);
+		switch (sortType) {
+			case SORT_BY_NAME:
+			printf("(NAME)");
+			break;
+			case SORT_BY_COUNT_DSC:
+			printf("(COUNT_DSC)");
+			break;
+			case SORT_BY_COUNT_ASC:
+			printf("(COUNT_ASC)");
+			break;
+			case SORT_BY_ALIAS:
+			printf("(ALIAS)");
+			break;
+			case SORT_BY_BASENAME:
+			printf("(BASENAME)");
+			break;
+			default:
+			printf("(***)");
+			break;
+		}
+		printf(")\n");
+		listDebugDetails(l);
 #ifdef	PROC_TRACE_SWITCH
-    }
+	}
 #endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
-	if (sortType == SORT_BY_BASENAME) {	/* special case */
+
+	if (sortType == SORT_BY_BASENAME) { /* special case */
 		l->sorted = SORT_BY_NAME;
-	}
-	else {
+	} else {
 		l->sorted = sortType;
 	}
+
 	if (l->used == 0) {
 #ifdef	LIST_DEBUG
 		Warn("\"%s\" is empty", l->name);
 #endif	/* LIST_DEBUG */
 		return;
 	}
+
 	switch (sortType) {
 #ifdef	QA_CHECKS
-		case UNSORTED:
-			Fatal("Sort-spec == UNSORTED");
-			break;
+	case UNSORTED:
+	Fatal("Sort-spec == UNSORTED");
+	break;
 #endif	/* QA_CHECKS */
-		case SORT_BY_NAME_ICASE:
-			f = strIcaseCompare;
+	case SORT_BY_NAME_ICASE:
+		f = strIcaseCompare;
 #ifdef	PROC_TRACE
-			fName = "strIcaseCompare";
+		fName = "strIcaseCompare";
 #endif	/* PROC_TRACE */
-			break;
-		case SORT_BY_NAME:
-			f = strCompare;
+		break;
+	case SORT_BY_NAME:
+		f = strCompare;
 #ifdef	PROC_TRACE
-			fName = "strCompare";
+		fName = "strCompare";
 #endif	/* PROC_TRACE */
-			break;
-		case SORT_BY_COUNT_DSC:
-			f = valCompareDsc;
+		break;
+	case SORT_BY_COUNT_DSC:
+		f = valCompareDsc;
 #ifdef	PROC_TRACE
-			fName = "valCompareDsc";
+		fName = "valCompareDsc";
 #endif	/* PROC_TRACE */
-			break;
-		case SORT_BY_COUNT_ASC:
-			f = valCompareAsc;
+		break;
+	case SORT_BY_COUNT_ASC:
+		f = valCompareAsc;
 #ifdef	PROC_TRACE
-			fName = "valCompareAsc";
+		fName = "valCompareAsc";
 #endif	/* PROC_TRACE */
-			break;
-		case SORT_BY_ALIAS:
+		break;
+	case SORT_BY_ALIAS:
 #ifdef	PROC_TRACE
-			fName = "bufCompare";
+		fName = "bufCompare";
 #endif	/* PROC_TRACE */
-			f = bufCompare;
-			break;
-		case SORT_BY_BASENAME:
+		f = bufCompare;
+		break;
+	case SORT_BY_BASENAME:
 #ifdef	PROC_TRACE
-			fName = "strCompareBasename";
+		fName = "strCompareBasename";
 #endif	/* PROC_TRACE */
-			f = strCompareBasename;
-			sortType = SORT_BY_NAME;
-			break;
-		default:
-			Fatal("Invalid sort-spec %d", sortType);
+		f = strCompareBasename;
+		sortType = SORT_BY_NAME;
+		break;
+	default:
+		Fatal("Invalid sort-spec %d", sortType);
 	}
-/* */
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("=> invoking qsort(): callback is %s()\n", fName);
+	traceFunc("=> invoking qsort(): callback is %s()\n", fName);
 #endif	/* PROC_TRACE */
-/* */
+
 	qsort(l->items, (size_t) l->used, sizeof(item_t), f);
 	return;
 }
@@ -699,112 +706,105 @@ void listSort(list_t *l, int sortType)
  * qsort utility-function to create an alphabetically sorted (ASCENDING)
  * [case-insensitive] list based on the string value in the item_t 'str' field
  */
-static int strIcaseCompare(item_t *p1, item_t *p2)
-{
-	int ret = strcasecmp(p1->str, p2->str);
-	return(ret ? ret : valCompareDsc(p1, p2));
+static int strIcaseCompare(item_t *p1, item_t *p2) {
+	int ret;
+
+	ret = strcasecmp(p1->str, p2->str);
+	return (ret ? ret : valCompareDsc(p1, p2));
 }
 
 /*
  * qsort utility-function to create an alphabetically sorted (ASCENDING)
  * list based on the string value in the item_t 'str' field
  */
-static int strCompare(item_t *p1, item_t *p2)
-{
-	int ret = strcmp(p1->str, p2->str);
-	return(ret ? ret : valCompareDsc(p1, p2));
+static int strCompare(item_t *p1, item_t *p2) {
+	int ret;
+
+	ret = strcmp(p1->str, p2->str);
+	return (ret ? ret : valCompareDsc(p1, p2));
 }
 
 /*
  * qsort utility-function to create an alphabetically sorted (ASCENDING)
  * list based on the path-basename of string value in the item_t 'str' field
  */
-static int strCompareBasename(item_t *p1, item_t *p2)
-{
-	int ret = strcmp(pathBasename(p1->str), pathBasename(p2->str));
-	return(ret ? ret : strCompare(p1, p2));
+static int strCompareBasename(item_t *p1, item_t *p2) {
+	int ret;
+
+	ret = strcmp(pathBasename(p1->str), pathBasename(p2->str));
+	return (ret ? ret : strCompare(p1, p2));
 }
 
 /*
  * qsort utility-function to create a numerically sorted (ASCENDING)
  * list based on the integer value in the item_t 'val' field
  */
-static int valCompareAsc(item_t *p1, item_t *p2)
-{
-	return(p1->val - p2->val);
+static int valCompareAsc(item_t *p1, item_t *p2) {
+	return (p1->val - p2->val);
 }
 
 /*
  * qsort utility-function to create a numerically sorted (DESCENDING)
  * list based on the integer value in the item_t 'val' field
  */
-static int valCompareDsc(item_t *p1, item_t *p2)
-{
-	return(p2->val - p1->val);
+static int valCompareDsc(item_t *p1, item_t *p2) {
+	return (p2->val - p1->val);
 }
 
 /*
  * qsort utility-function to create an alphabetically sorted (ASCENDING)
  * list based on the string value in the item_t 'buf' field
  */
-static int bufCompare(item_t *p1, item_t *p2)
-{
+static int bufCompare(item_t *p1, item_t *p2) {
 	int ret = strcmp(p1->buf, p2->buf);
-	return(ret ? ret : valCompareDsc(p1, p2));
+	return (ret ? ret : valCompareDsc(p1, p2));
 }
 
 /*
  * Be careful about calling this function; some lists use the 'val'
  * field as a flag, others use it as a count!
  */
-int listCount(list_t *l)
-{
-	register int i, tot;
-	register item_t *p;
-/* */
+int listCount(list_t *l) {
+	int i;
+	int total;
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listCount(%p)\n", l);
+	traceFunc("== listCount(%p)\n", l);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
+
 #if	defined(QA_CHECKS) || defined(LIST_DEBUG)
 	listValidate(l, NO);
 #endif	/* QA_CHECKS || LIST_DEBUG */
-	for (i = tot = 0, p = l->items; i < l->used; i++, p++) {
-		if (p->val > 0) {
-			tot += p->val;	/* sum POSITIVE 'val' values */
+	total = 0;
+	for (i = 0; i < l->used; i++) {
+		if (l->items[i].val > 0) {
+			total += l->items[i].val; /* sum POSITIVE 'val' values */
 		}
-#ifdef	LATER
-		if (p->val2 > 0) {
-			tot += p->val2;	/* add in POSITIVE 'val2' values */
-		}
-#endif 	/* LATER */
 	}
-	return(tot);
+	return (total);
 }
 
-void listDump(list_t *l, int verbose)
-{
-	register item_t *p;
-	register int i, max = (verbose ? l->size : l->used);
-/* */
+/**
+ * listDump
+ * \brief print the passed in list
+ *
+ * @param *l the list to dump
+ * @param verbose flag, print more
+ *
+ * \callgraph
+ */
+void listDump(list_t *l, int verbose) {
+	item_t *p;
+	int i;
+	int max = (verbose ? l->size : l->used);
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== listDump(%p, %d)\n", l, verbose);
+	traceFunc("== listDump(%p, %d)\n", l, verbose);
 	listDebugDetails(l);
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
 #endif	/* PROC_TRACE */
-/* */
+
+	/*MD: why should an empty list be fatal?  Just return....? */
 	if (l == NULL_LIST) {
 		Fatal("NULL list passed to listDump()");
 	}
@@ -815,36 +815,37 @@ void listDump(list_t *l, int verbose)
 		return;
 	}
 	if (verbose < 0) {
-		printf("** %s (size %d, used %d, ix %d, sort %d desc %d) == %d\n",
-		    l->name, l->size, l->used, l->ix, l->sorted, l->desc,
-		    l->size*sizeof(item_t));
+		printf("** %s (size %d, used %d, ix %d, sort %d desc %d) == %ud\n",
+				l->name, l->size, l->used, l->ix, l->sorted, l->desc,
+						sizeof(item_t));
 		return;
 	}
 	if (verbose || max) {
 		printf("Contents of %s:\n", l->name);
-		printf("    ... @%p (size %d, used %d, ix %d, sort %d desc %d)\n",
-		    l, l->size, l->used, l->ix, l->sorted, l->desc);
+		printf("    ... @%p (size %d, used %d, ix %d, sort %d desc %d)\n", l,
+				l->size, l->used, l->ix, l->sorted, l->desc);
 	}
-/*
- * Brute-force a walk through the list contents.  This function could
- * be called during a loop (while(listIterate(&list))) and we CANNOT
- * mess with the 'ix' field for this list as listIterate() does!
- */
-	for (i = 0, p = l->items; i < l->used; p++, i++) {
+	/*
+	 * Brute-force a walk through the list contents.  This function could
+	 * be called during a loop (while(listIterate(&list))) and we CANNOT
+	 * mess with the 'ix' field for this list as listIterate() does!
+	 */
+	for (i = 0; i < l->used; i++) {
+		p = &(l->items[i]);
 		if (verbose) {
 			printf("[%c] ", (i < l->used ? 'x' : ' '));
 		}
-		printf("#%03d: str %p buf %p (val %d, val2 %d val3 %d)\n",
-		    i, p->str, p->buf, p->val, p->val2, p->val3);
+		printf("#%03d: str %p buf %p (val %d, val2 %d val3 %d)\n", i, p->str,
+				p->buf, p->val, p->val2, p->val3);
 		if (i < l->used) {
 			printf("    str: \"%s\"\n", p->str);
 			if (p->buf != NULL_STR) {
-				printf("    ... buf: \"%s\"\n", p->buf);
+				printf("    ... buf: \"%s\"\n", (char *)p->buf);
 			}
 		}
 	}
 	return;
-}
+} /* listDump */
 
 #if	defined(PROC_TRACE) || defined(LIST_DEBUG)
 void listDebugDetails(list_t *l)
