@@ -22,8 +22,12 @@ void listInit(list_t *l, int size, char *label);
 void listClear(list_t *l, int deallocFlag);
 item_t *listGetItem(list_t *l, char *s);
 item_t *listAppend(list_t *l, char *s);
+
+#ifdef notdef
 item_t *listLookupName(list_t *l, char *s);
 item_t *listLookupAlias(list_t *l, char *s);
+#endif /* notdef */
+
 item_t *listIterate(list_t *l);
 void listIterationReset(list_t *l);
 int listDelete(list_t *l, item_t *p);
@@ -31,8 +35,7 @@ void listSort(list_t *l, int sortType);
 int listCount(list_t *l);
 void listDump(list_t *l, int verbose);
 
-#if	defined(PROC_TRACE) || defined(LIST_DEBUG)
-void listDebugDetails(list_t *l);
-#endif	/* PROC_TRACE || LIST_DEBUG */
+#define DEALLOC_LIST	1
+#define NOTOUCH_LIST	0
 
 #endif /* _LIST_H */
