@@ -15,6 +15,14 @@
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 ***************************************************************/
+/* Equivalent to core nomos v1.29 */
+
+/**
+ * \file utilc
+ * \brief misc utilites
+ *
+ * @version "$Id: util.c 3210 2010-06-05 18:32:13Z bobgo $"
+ */
 #include <stdarg.h>
 #include <stdio.h>
 #include "nomos.h"
@@ -37,6 +45,7 @@ static char grepzone[10485760];	/* 10M for now, adjust if needed */
 static va_list ap;
 static char utilbuf[myBUFSIZ];
 static struct mm_cache mmap_data[MM_CACHESIZE];
+static char cmdBuf[512];
 
 
 #ifdef	MEMORY_TRACING
@@ -50,11 +59,9 @@ void memCacheDump();
 int isDIR(char *dpath)
 {
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isDIR(%s)\n", dpath);
+	traceFunc("== isDIR(%s)\n", dpath);
 #endif	/* PROC_TRACE */
+
     return(isINODE(dpath, S_IFDIR));
 }
 
@@ -69,26 +76,20 @@ void unbufferFile(FILE *fp)
 int isEMPTYFILE(char *fpath)
 {
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isEMPTYFILE(%s)\n", fpath);
+	traceFunc("== isEMPTYFILE(%s)\n", fpath);
 #endif	/* PROC_TRACE */
 
     if (!isFILE(fpath)) {
 	return(0);
     }
-    return(gl.stbuf.st_size == 0);
+    return(cur.stbuf.st_size == 0);
 }
 
 
 int isBLOCK(char *bpath)
 {
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isBLOCK(%s)\n", bpath);
+	traceFunc("== isBLOCK(%s)\n", bpath);
 #endif	/* PROC_TRACE */
 
     return(isINODE(bpath, S_IFBLK));
@@ -98,11 +99,9 @@ int isBLOCK(char *bpath)
 int isCHAR(char *cpath)
 {
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isCHAR(%s)\n", cpath);
+	traceFunc("== isCHAR(%s)\n", cpath);
 #endif	/* PROC_TRACE */
+
     return(isINODE(cpath, S_IFCHR));
 }
 
@@ -110,11 +109,9 @@ int isCHAR(char *cpath)
 int isPIPE(char *ppath)
 {
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isPIPE(%s)\n", ppath);
+	traceFunc("== isPIPE(%s)\n", ppath);
 #endif	/* PROC_TRACE */
+
     return(isINODE(ppath, S_IFIFO));
 }
 
@@ -122,11 +119,9 @@ int isPIPE(char *ppath)
 int isSYMLINK(char *spath)
 {
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isSYMLINK(%s)\n", spath);
+	traceFunc("== isSYMLINK(%s)\n", spath);
 #endif	/* PROC_TRACE */
+
     return(isINODE(spath, S_IFLNK));
 }
 
@@ -134,13 +129,12 @@ int isSYMLINK(char *spath)
 int isINODE(char *ipath, int typ)
 {
     int ret;
+
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isINODE(%s, 0x%x)\n", ipath, typ);
+	traceFunc("== isINODE(%s, 0x%x)\n", ipath, typ);
 #endif	/* PROC_TRACE */
-    if ((ret = stat(ipath, &gl.stbuf)) < 0) {
+
+    if ((ret = stat(ipath, &cur.stbuf)) < 0) {
 	/*
 	  IF we're trying to stat() a file that doesn't exist, 
 	  that's no biggie.
@@ -151,12 +145,12 @@ int isINODE(char *ipath, int typ)
 	}
 	perror(ipath);
 	mySystem("ls -l '%s'", ipath);
-	Bail(1);
+	Bail(10);
     }
     if (typ == 0) {
 	return(1);
     }
-    return((int)(gl.stbuf.st_mode & S_IFMT & typ));
+    return((int)(cur.stbuf.st_mode & S_IFMT & typ));
 }
 
 
@@ -166,10 +160,7 @@ char *newReloTarget(char *basename)
     int i;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== newReloTarget(%s)\n", basename);
+	traceFunc("== newReloTarget(%s)\n", basename);
 #endif	/* PROC_TRACE */
 
     for (i = 0; i < MAX_RENAME; i++) {
@@ -201,10 +192,7 @@ char *memAllocTagged(int size, char *name)
      */
 
 #if	defined(PROC_TRACE) || defined(MEM_ACCT)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== memAllocTagged(%d, \"%s\")\n", size, name);
+	traceFunc("== memAllocTagged(%d, \"%s\")\n", size, name);
 #endif	/* PROC_TRACE || MEM_ACCT */
 
     if (size < 1) {
@@ -246,10 +234,7 @@ void memFreeTagged(void *ptr, char *note)
     int i;
 
 #if	defined(PROC_TRACE) || defined(MEM_ACCT)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== memFree(%p, \"%s\")\n", ptr, note);
+	traceFunc("== memFree(%p, \"%s\")\n", ptr, note);
 #endif	/* PROC_TRACE || MEM_ACCT */
 
 #ifdef	MEMORY_TRACING
@@ -321,10 +306,7 @@ char *findBol(char *s, char *upperLimit)
     char *cp;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== findBol(%p, %p)\n", s, upperLimit);
+	traceFunc("== findBol(%p, %p)\n", s, upperLimit);
 #endif	/* PROC_TRACE */
 
     if (s == NULL_STR || upperLimit == NULL_STR) {
@@ -356,10 +338,7 @@ char *findEol(char *s)
     char *cp;
     
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== findEol(%p)\n", s);
+	traceFunc("== findEol(%p)\n", s);
 #endif	/* PROC_TRACE */
     
     if (s == NULL_STR) {
@@ -377,34 +356,6 @@ char *findEol(char *s)
 }
 
 
-void changeDir(char *pathname)
-{
-    /*
-     * we die here if the chdir() fails.
-     */
-
-#if	defined(PROC_TRACE) || defined(UNPACK_DEBUG) || defined(CHDIR_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== changeDir(%s)\n", pathname);
-#endif	/* PROC_TRACE || UNPACK_DEBUG || CHDIR_DEBUG */
-
-    if (chdir(pathname) < 0) {
-	perror(pathname);
-	Fatal("chdir(\"%s\") fails", pathname);
-    }
-    if (getcwd(gl.cwd, sizeof(gl.cwd)) == NULL_STR) {
-	perror("getcwd(changeDir)");
-	Bail(1);
-    }
-    gl.cwdLen = (int) strlen(gl.cwd);
-#ifdef	CHDIR_DEBUG
-    printf("DEBUG: now in \"%s\"\n", gl.cwd);
-#endif	/* CHDIR_DEBUG */
-    return;
-}
-
 void renameInode(char *oldpath, char *newpath)
 {
     int err = 0;
@@ -413,10 +364,7 @@ void renameInode(char *oldpath, char *newpath)
      */
 
 #if defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== renameInode(%s, %s)\n", oldpath, newpath);
+	traceFunc("== renameInode(%s, %s)\n", oldpath, newpath);
 #endif	/* PROC_TRACE || UNPACK_DEBUG */
 
 #ifdef	DEBUG
@@ -441,31 +389,6 @@ void renameInode(char *oldpath, char *newpath)
 }
 
 
-void unlinkFile(char *pathname)
-{
-    /*
-     * we die here if the unlink() fails.
-     */
-
-#if defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== unlinkFile(%s)\n", pathname);
-#endif	/* PROC_TRACE || UNPACK_DEBUG */
-
-    if (unlink(pathname) < 0) {
-	(void) chmod(pathname, 0777);
-	if (unlink(pathname) < 0) {
-	    perror(pathname);
-	    (void) mySystem("ls -ldi '%s'", pathname);
-	    Fatal("unlink(\"%s\") fails", pathname);
-	}
-    }
-    return;
-}
-
-
 void chmodInode(char *pathname, int mode)
 {
 /*
@@ -473,10 +396,7 @@ void chmodInode(char *pathname, int mode)
  */
 
 #if defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== chmodInode(%s, 0%o)\n", pathname, mode);
+	traceFunc("== chmodInode(%s, 0%o)\n", pathname, mode);
 #endif	/* PROC_TRACE || UNPACK_DEBUG */
 
     if (chmod(pathname, mode) < 0) {
@@ -496,10 +416,7 @@ FILE *fopenFile(char *pathname, char *mode)
  */
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== fopenFile(%s, \"%s\")\n", pathname, mode);
+	traceFunc("== fopenFile(%s, \"%s\")\n", pathname, mode);
 #endif	/* PROC_TRACE */
 
     if ((fp = fopen(pathname, mode)) == (FILE *) NULL) {
@@ -509,6 +426,22 @@ FILE *fopenFile(char *pathname, char *mode)
     return(fp);
 }
 
+/*
+ *
+ Save for now, could be useful for debugging
+
+static void printListToFile(list_t *l, char *filename, char *mode) {
+    FILE *fp;
+    item_t *ip;
+
+    fp = fopenFile(filename, mode);
+    while ((ip = listIterate(l)) != NULL_ITEM) {
+        fprintf(fp, "%s\n", ip->str);
+    }
+    (void) fclose(fp);
+    return;
+}
+*/
 
 FILE *popenProc(char *command, char *mode)
 {
@@ -519,10 +452,7 @@ FILE *popenProc(char *command, char *mode)
  */
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== popenProc(\"%s\", %s)\n", command, mode);
+	traceFunc("== popenProc(\"%s\", %s)\n", command, mode);
 #endif	/* PROC_TRACE */
 
     if ((pp = popen(command, mode)) == (FILE *) NULL) {
@@ -548,10 +478,7 @@ char *wordCount(char *textp)
     char *cp;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== wordCount(%p)\n", textp);
+	traceFunc("== wordCount(%p)\n", textp);
 #endif	/* PROC_TRACE */
 
     words = 0;
@@ -583,13 +510,11 @@ char *wordCount(char *textp)
 	}
     }
     (void) sprintf(wcbuf, "%d lines, %d words", lines, words);
-#ifdef notdef
     /*
      * Save these values for use elsewhere, too.
      */
     cur.nWords = words;
     cur.nLines = lines;
-#endif /* notdef */
     return(wcbuf);
 }
 
@@ -600,10 +525,7 @@ char *copyString(char *s, char *label)
     int len;
     
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== copyString(%p, \"%s\")\n", s, label);
+	traceFunc("== copyString(%p, \"%s\")\n", s, label);
 #endif	/* PROC_TRACE */
     
     cp = memAlloc(len=(strlen(s)+1), label);
@@ -620,10 +542,7 @@ char *pathBasename(char *path)
     char *cp;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== pathBasename(\"%s\")\n", path);
+	traceFunc("== pathBasename(\"%s\")\n", path);
 #endif	/* PROC_TRACE */
 
     cp = strrchr(path, '/');
@@ -640,10 +559,8 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
     static char *ibuf = NULL;
     static int bufmax = 0;
     char *sep = _REGEX(_UTIL_XYZZY);
-#ifdef	SHOW_LOCATION
     item_t *p;
-    item_t *bp;
-#endif	/* SHOW_LOCATION */
+    item_t *bp = 0;
     char *fileeof;
     char *start;
     char *end;
@@ -655,10 +572,7 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
     int regexFlags = REG_ICASE|REG_EXTENDED;
 
 #if defined(PROC_TRACE) || defined(PHRASE_DEBUG) || defined(DOCTOR_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== getInstances(%p, %d, %d, %d, \"%s\", %d)\n", textp, size,
+	traceFunc("== getInstances(%p, %d, %d, %d, \"%s\", %d)\n", textp, size,
 	       nBefore, nAfter, regex, recordOffsets);
 #endif	/* PROC_TRACE || PHRASE_DEBUG || DOCTOR_DEBUG */
 
@@ -668,17 +582,17 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 #endif	/* PHRASE_DEBUG */
 	return(NULL_STR);
     }
-#ifdef	SHOW_LOCATION
     /*
      * The global 'offsets list' is indexed by the seed/key (a regex) that we
      * use for doctoring buffers... each entry will contain a list (containing
      * the "paragraphs" that match the key) AND its size (e.g., # of 'chunks'),
      * which also means, if there are N chunks, there are N-1 'xyzzy' separators.
      */
-    p = listGetItem(&gl.offList, regex);
-    p->seqNo = gl.offList.used;
+    p = listGetItem(&cur.offList, regex);
+    p->seqNo = cur.offList.used;
     p->nMatch = 0;
     if (recordOffsets) {
+    if (p->bList) free(p->bList);
 	p->bList = (list_t *)memAlloc(sizeof(list_t), MTAG_LIST);
 	(void) sprintf(utilbuf, "\"%c%c%c%c%c%c%c%c%c%c\" match-list",
 		       *regex, *(regex+1), *(regex+2), *(regex+3), *(regex+4),
@@ -686,7 +600,7 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 #ifdef	PHRASE_DEBUG
 	printf("Creating %s\n", utilbuf);
 #endif	/* PHRASE_DEBUG */
-	listInit(p->bList, 0, utilbuf);
+	listInit(p->bList, 0, utilbuf); /*  <- MEMORY LEAK from p->bList->items not freed */
 #ifdef	QA_CHECKS
 	p->val3++;	/* sanity-check -- should never be >1 ! */
 	if (p->val3 > 1) {
@@ -695,7 +609,6 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 	}
 #endif	/* QA_CHECKS */
     }
-#endif	/* SHOW_LOCATION */
 #ifdef	REUSE_STATIC_MEMORY
     if (ibuf == NULL_STR) {		/* first time, uninitialized */
 	ibuf = grepzone;
@@ -719,9 +632,9 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
      */
 #ifdef	PHRASE_DEBUG
     printf("getInstances: \"%s\" [#1] in buf [%d-%d]\n", regex,
-	   gl.regm.rm_so, gl.regm.rm_eo-1);
+	   cur.regm.rm_so, cur.regm.rm_eo-1);
     printf("Really in the buffer: [");
-    for (cp = textp+gl.regm.rm_so; cp < textp+gl.regm.rm_eo; cp++) {
+    for (cp = textp + cur.regm.rm_so; cp < (textp + cur.regm.rm_eo); cp++) {
 	printf("%c", *cp);
     }
     printf("]\n");
@@ -734,7 +647,6 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
     curptr = textp;
     fileeof = (char *) (textp+size);
     while (notDone) {	/* curptr is the 'current block' ptr */
-#ifdef	SHOW_LOCATION
 	p->nMatch++;
 #ifdef	PHRASE_DEBUG
 	printf("... found Match #%d\n", p->nMatch);
@@ -743,17 +655,16 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 	    (void) sprintf(utilbuf, "buf%05d", p->nMatch);
 	    bp = listGetItem(p->bList, utilbuf);
 	}
-#endif	/* SHOW_LOCATION */
-	start = findBol(curptr+gl.regm.rm_so, textp);
+	start = findBol(curptr + cur.regm.rm_so, textp);
 	/*
 	 * Go to the beggining of the current line and, if nBefore > 0, go 'up'
 	 * in the text "$nBefore" lines.  Count 2-consecutive EOL-chars as one
 	 * line since some text files use <CR><LF> as line-terminators.
 	 */
-	if (nBefore > 0 && start > textp) {
-	    for (i = 0; i < nBefore && start > textp; i++) {
+	if ((nBefore > 0) && (start > textp)) {
+	    for (i = 0; (i < nBefore) && (start > textp); i++) {
 		start -= 2;
-		if (start > textp && isEOL(*start)) {
+		if ((start > textp) && isEOL(*start)) {
 		    start--;
 		}
 		if (start > textp) {
@@ -764,11 +675,9 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 #endif	/* PHRASE_DEBUG */
 	    }
 	}
-#ifdef	SHOW_LOCATION
 	if (recordOffsets) {
 	    bp->bStart = start-textp;
 	}
-#endif	/* SHOW_LOCATION */
 	/*
 	 * Now do what "grep -A $nAfter _filename+" does.
 	 *****
@@ -785,8 +694,9 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 	 * have our pattern.
 	 */
 	do {
-	    curptr += gl.regm.rm_eo;
-	    if ((end = findEol(curptr)) < fileeof) {
+	    curptr += cur.regm.rm_eo;
+	    end = findEol(curptr);
+	    if (end < fileeof) {
 		end++;	/* first char past end-of-line */
 	    }
 	    if (nAfter > 0) {
@@ -794,7 +704,8 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 		    if (isEOL(*end)) {	/* double-EOL */
 			end++;		/* <CR><LF>? */
 		    }
-		    if ((end = findEol(end)) == NULL_STR) {
+		    end = findEol(end);
+		    if (end == NULL_STR) {
 			Fatal("lost the end-of-line");
 		    }
 		    if (*end == NULL_CHAR) {
@@ -804,7 +715,7 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 			break;
 		    }
 		}
-		if (end < fileeof && *end) {
+		if ((end < fileeof) && *end) {
 		    end++;	/* past newline-char */
 		}
 	    }
@@ -819,16 +730,16 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 	    if (notDone) {	/* another match? */
 #ifdef	PHRASE_DEBUG
 		printf("... next match @ %d:%d (end=%d)\n",
-		       curptr-textp+gl.regm.rm_so,
-		       curptr-textp+gl.regm.rm_eo-1, end-textp);
+		       curptr - textp + cur.regm.rm_so,
+		       curptr - textp + cur.regm.rm_eo - 1, end - textp);
 #endif	/* PHRASE_DEBUG */
 #ifdef	QA_CHECKS
-		if (curptr+gl.regm.rm_eo > fileeof) {
+		if ((curptr + cur.regm.rm_eo) > fileeof) {
 		    Assert(YES, "Too far into file!");
 		}
 #endif	/* QA_CHECKS */
 		/* next match OUTSIDE the text we've already saved? */
-		if (curptr+gl.regm.rm_eo > end) {
+		if ((curptr + cur.regm.rm_eo) > end) {
 		    break;
 		}
 		/* else, next match IS within the text we're looking at! */
@@ -842,7 +753,6 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 	 */
 	save = *end;
 	*end = NULL_CHAR;	/* char PAST the newline! */
-#ifdef	SHOW_LOCATION
 	if (recordOffsets) {
 	    bp->bLen = end-start;
 	    bp->buf = copyString(start, MTAG_TEXTPARA);
@@ -853,7 +763,6 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 		   *(end-6), *(end-5), *(end-4), *(end-3), *(end-2));
 #endif	/* PHRASE_DEBUG */
 	}
-#endif	/* SHOW_LOCATION */
 	newDataLen = end-start+(notDone ? strlen(sep)+1 : 0);
 	while (buflen+newDataLen > bufmax) {
 	    char *new;
@@ -913,13 +822,8 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
 	       regex, strlen(ibuf), ibuf);
 #endif	/* PHRASE_DEBUG */
     }
-#if	0
-#ifdef	SHOW_LOCATION
-    printf("\"%s\": matches == %d\n", p->str, p->nMatch);
-    /*listDump(&gl.offList, YES);*/
-#endif	/* SHOW_LOCATION */
-#endif
-#if	defined(PHRASE_DEBUG) || defined(DOCTOR_DEBUG)
+
+#if defined(PHRASE_DEBUG) || defined(DOCTOR_DEBUG)
     printf("getInstances(\"%s\"): Found %d bytes of data...\n", regex,
 	   buflen-1);
 #endif	/* PHRASE_DEBUG || DOCTOR_DEBUG */
@@ -927,7 +831,8 @@ char *getInstances(char *textp, int size, int nBefore, int nAfter, char *regex,
     printf("getInstances(\"%s\"): buffer %p --------\n%s\n========\n",
 	   regex, ibuf, ibuf);
 #endif	/* PHRASE_DEBUG */
-    return(ibuf);
+
+  return(ibuf);
 }
 
 
@@ -976,40 +881,21 @@ void memStats(char *s)
 void makeSymlink(char *path)
 {
 #if defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== makeSymlink(%s)\n", path);
+	traceFunc("== makeSymlink(%s)\n", path);
 #endif	/* PROC_TRACE || UNPACK_DEBUG */
 
-    (void) sprintf(gl.cmdBuf, ".%s", strrchr(path, '/'));
-    if (symlink(path, gl.cmdBuf) < 0) {
-	perror(gl.cmdBuf);
-	Fatal("Failed: symlink(%s, %s)", path, gl.cmdBuf);
+    (void) sprintf(cmdBuf, ".%s", strrchr(path, '/'));
+    if (symlink(path, cmdBuf) < 0) {
+	perror(cmdBuf);
+	Fatal("Failed: symlink(%s, %s)", path, cmdBuf);
     }
     return;
 }
 
 
+#ifdef notdef
 int fileTypeIs(char *pathname, int index, char *magicData)
 {
-
-#if defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-    extern lic_t licText[];
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch) {
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== fileTypeIs(%s, %d, \"%s\")\n", pathname, index,
-	       magicData);
-
-#ifndef	UNPACK_DEBUG
-	printf("... regex is \"%s\"\n", _REGEX(index));
-#endif	/* not UNPACK_DEBUG */
-#ifdef	PROC_TRACE_SWITCH
-    }
-#endif	/* PROC_TRACE_SWITCH */
-#endif	/* PROC_TRACE || UNPACK_DEBUG */
-
     if (idxGrep(index, magicData, REG_ICASE|REG_EXTENDED)) {
 	return(1);
     }
@@ -1046,9 +932,9 @@ int fileIsShar(char *textp, char *magicData)
     return(0);
 #endif	/* not DEBUG */
 }
+#endif /* notdef */
 
 
-#ifdef notdef
 /*
    CDB -- Need to review this code, particularly for the use of an
    external file (Nomos.strings.txt). Despite the fact that variable 
@@ -1071,10 +957,7 @@ void printRegexMatch(int n, int cached)
     char *textp;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== printRegexMatch(%d, %d)\n", n, cached);
+    traceFunc("== printRegexMatch(%d, %d)\n", n, cached);
 #endif	/* PROC_TRACE */
 
     if (*debugStr == NULL_CHAR) {
@@ -1083,8 +966,8 @@ void printRegexMatch(int n, int cached)
 	printf("File: %s\n", debugStr);
 #endif	/* DEBUG */
     }
-    save_so = gl.regm.rm_so;
-    save_eo = gl.regm.rm_eo;
+    save_so = cur.regm.rm_so;
+    save_eo = cur.regm.rm_eo;
     if (isFILE(debugStr)) {
 	if ((match = (gl.flags & FL_SAVEBASE))) { /* assignment is deliberate */
 	    gl.flags &= ~FL_SAVEBASE;
@@ -1097,17 +980,18 @@ void printRegexMatch(int n, int cached)
 	if (strGrep(misc, textp, REG_EXTENDED)) {
 #ifdef	DEBUG
 	    printf("Patt: %s\nMatch: %d:%d\n", misc,
-		   gl.regm.rm_so, gl.regm.rm_eo);
+		   cur.regm.rm_so, cur.regm.rm_eo);
 #endif	/* DEBUG */
-	    x = textp + gl.regm.rm_so;
-	    cp = textp + gl.regm.rm_so;
+	    x = textp + cur.regm.rm_so;
+	    cp = textp + cur.regm.rm_so;
 	    *x = NULL_CHAR;
 	    while (*--x != '[') {
 		if (x == textp) {
 		    Fatal("Cannot locate debug symbol");
 		}
 	    }
-	    (void) strncpy(misc, ++x, cp-x); /* CDB - Fix */
+	    ++x; /* CDB - Moved from line below. Hope this is what was intended.*/
+	    (void) strncpy(misc, x, cp - x); /* CDB - Fix */
 	    misc[cp-x] = NULL_CHAR;
 	} else {
 	    (void) strcpy(misc, "?");
@@ -1117,11 +1001,11 @@ void printRegexMatch(int n, int cached)
 	    gl.flags |= FL_SAVEBASE;
 	}
 #ifdef	DEBUG
-	printf("RESTR [%d:%d]\n", gl.regm.rm_so, gl.regm.rm_eo);
+	printf("RESTR [%d:%d]\n", cur.regm.rm_so, cur.regm.rm_eo);
 #endif	/* DEBUG */
     }
-    gl.regm.rm_so = save_so;
-    gl.regm.rm_eo = save_eo;
+    cur.regm.rm_so = save_so;
+    cur.regm.rm_eo = save_eo;
     printf("%s regex %d ", cached ? "Cached" : "Found", n);
     if (x) {
 	printf("(%s) ", misc);
@@ -1135,7 +1019,6 @@ void printRegexMatch(int n, int cached)
 #endif	/* DEBUG */
     return;
 }
-#endif /* notdef */
 
 
 /*
@@ -1147,46 +1030,25 @@ void printRegexMatch(int n, int cached)
 char *mmapFile(char *pathname)	/* read-only for now */
 {
     struct mm_cache *mmp;
-    static int first = 1;
     int i;
     int n;
     int rem;
     char *cp;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== mmapFile(%s)\n", pathname);
+	traceFunc("== mmapFile(%s)\n", pathname);
 #endif	/* PROC_TRACE */
 
-    /* 
-     * Static storage is _supposed_ to be initialized @ 0.  Do we need this?
-     */
-    if (first) {
-#if	(DEBUG > 3)
-	printf("MMapFile: first call\n");
-#endif	/* DEBUG > 3 */
-	for (mmp = mmap_data, i = 0; i < MM_CACHESIZE; i++) {
-	    if (mmp->inUse) {
-		printf("Uninitialized entry %d\n", i);
-		mmp->inUse = 0;
-	    }
-	}
-	first = 0;
-    }
-    /* CDB - Changed this. Could possibly have broken it. */
-    i = 0;
-    for (mmp = mmap_data; i < MM_CACHESIZE; mmp++) {
-	if (mmp->inUse == 0) {
-	    break;
-	}
-	i++;
+    for (mmp = mmap_data, i = 0; i < MM_CACHESIZE; i++, mmp++) {
+        if (mmp->inUse == 0) {
+            break;
+        }
     }
+
     if (i == MM_CACHESIZE) {
-	fprintf(stderr, "mmap-cache too small [%d]!\n", MM_CACHESIZE);
+	printf("mmap-cache too small [%d]!\n", MM_CACHESIZE);
 	mmapOpenListing();
-	Bail(1);
+	Bail(12);
     }
 
     if ((mmp->fd = open(pathname, O_RDONLY)) < 0) {
@@ -1203,29 +1065,39 @@ char *mmapFile(char *pathname)	/* read-only for now */
 	(void) mySystem("ls -l %s", pathname);
 	Fatal("%s: open failure!", pathname);
     }
-    if (fstat(mmp->fd, &gl.stbuf) < 0) {
-	fprintf(stderr, "fstat failure!\n");
+
+    if (fstat(mmp->fd, &cur.stbuf) < 0) {
+	printf("fstat failure!\n");
 	perror(pathname);
-	Bail(1);
+	Bail(13);
     }
-    if (S_ISDIR(gl.stbuf.st_mode)) {
-	fprintf(stderr, "mmapFile(%s): is a directory\n", pathname);
-	Bail(1);
+    if (S_ISDIR(cur.stbuf.st_mode)) {
+	printf("mmapFile(%s): is a directory\n", pathname);
+	Bail(14);
     }
     (void) strcpy(mmp->label, pathname);
-    if (gl.stbuf.st_size) {
-	mmp->size = gl.stbuf.st_size+1;
+    if (cur.stbuf.st_size) {
+	mmp->size = cur.stbuf.st_size + 1;
 	mmp->mmPtr = memAlloc(mmp->size, MTAG_MMAPFILE);
 #ifdef	DEBUG
 	printf("+MM: %d @ %p\n", mmp->size, mmp->mmPtr);
 #endif	/* DEBUG */
+
+  /* Limit scan to first MAX_SCANBYTES
+   * We have never found a license more than 64k into a file.
+   */
+  if (mmp->size > MAX_SCANBYTES) mmp->size = MAX_SCANBYTES;
+
 	rem = mmp->size-1;
 	cp = mmp->mmPtr;
 	while (rem > 0) {
-	    if ((n = (int) read(mmp->fd, cp, (size_t) rem)) < 0) {
-		perror("read");
-		Bail(1);
-	    }
+    if ((n = (int) read(mmp->fd, cp, (size_t) rem)) < 0) {
+      /* log error and move on.  This way error will be logged
+       * but job will continue
+       */
+      printf("WARNING nomos read error: %s, file: %s, read size: %d, pfile_pk: %ld\n", strerror(errno), pathname, rem, cur.pFileFk);
+      break;
+    }
 	    rem -= n;
 	    cp += n;
 	}
@@ -1270,10 +1142,7 @@ void munmapFile(void *ptr)
     int i;
     
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== munmapFile(%p)\n", ptr);
+	traceFunc("== munmapFile(%p)\n", ptr);
 #endif	/* PROC_TRACE */
 
     if (ptr == (void *) NULL) {
@@ -1297,7 +1166,7 @@ void munmapFile(void *ptr)
 #endif
 	    if (close(mmp->fd) < 0) {
 		perror("close");
-		Bail(1);
+		Bail(16);
 	    }
 #ifdef	PARANOID
 	    mmp->buf = (void *) NULL;
@@ -1315,45 +1184,14 @@ void munmapFile(void *ptr)
 }
 
 
-int fileLineCount(char *pathname)
-{
-    char *filep;
-    int i;
-    /*
-     * We need the file size to know when we're at the end-of-file.
-     *****
-     * When we call mmapFile(), we automatically get a stat(2) structure
-     * populated for the file we're opening, so we can get the file size
-     * from there.  Maybe that's kludgy, and maybe it's 'efficient design'. 
-     */
-
-#ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== fileLineCount(%s)\n", pathname);
-#endif	/* PROC_TRACE */
-
-    if ((filep = mmapFile(pathname)) == NULL_STR) {
-	return(0);
-    }
-    i = bufferLineCount(filep, gl.stbuf.st_size);
-    munmapFile(filep);
-    return(i);
-}
-
-
 int bufferLineCount(char *p, int len)
 {
     char *cp; 
-    char *eofaddr;
+    char *eofaddr = NULL;
     int i;
     
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== bufferLineCount(%p, %d)\n", p, len);
+	traceFunc("== bufferLineCount(%p, %d)\n", p, len);
 #endif	/* PROC_TRACE */
 
     if (eofaddr == p) {
@@ -1372,56 +1210,12 @@ int bufferLineCount(char *p, int len)
 }
 
 
-/*
- * like strcmp(), but operate on contents of files
- */
-int fileCompare(char *f1, char *f2)
-{
-    int size1;
-    int size2;
-    int ret;
-    char *base1;
-    char *base2;
-
-#ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== fileCompare(%s, %s)\n", f1, f2);
-#endif	/* PROC_TRACE */
-
-    base1 = mmapFile(f1);
-    size1 = (int) gl.stbuf.st_size;
-    base2 = mmapFile(f2);
-    size2 = (int) gl.stbuf.st_size;
-    if (size1 == 0 && size2 == 0) {
-	ret = 0;
-    } else if (size1 < size2) {
-	ret = -1;
-    } else if (size1 > size2) {
-	ret = 1;
-    } else {
-	ret = strcmp(base1, base2);
-    }
-    if (base1) {
-	munmapFile(base1);
-    }
-    if (base2) {
-	munmapFile(base2);
-    }
-    return(ret);
-}
-
-
 void appendFile(char *pathname, char *str)
 {
     FILE *fp;
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== appendFile(%s, \"%s\")\n", pathname, str);
+	traceFunc("== appendFile(%s, \"%s\")\n", pathname, str);
 #endif	/* PROC_TRACE */
 
     fp = fopenFile(pathname, "a+");
@@ -1431,42 +1225,7 @@ void appendFile(char *pathname, char *str)
 }
 
 
-void dumpFile(FILE *fp, char *pathname, int logFlag)
-{
-    char *filep;
-    /*
-     * Dump the contents of a file -- this utility MAY go away later!
-     */
-    /* */
-#ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== dumpFile(%p, %s, %d)\n", fp, pathname, logFlag);
-#endif	/* PROC_TRACE */
-    /* */
-    if (!isFILE(pathname)) {
-#ifdef	DEBUG
-	printf("%s: NO SUCH FILE\n", pathname);
-#endif	/* DEBUG */
-	perror(pathname);
-	return;
-    }
-    if (gl.stbuf.st_size == 0) {
-	printf("%s: EMPTY\n", pathname);
-	return;
-    }
-    if ((filep = mmapFile(pathname)) == NULL_STR) {
-	return;
-    }
-    fprintf(fp, "%s", filep);
-    munmapFile(filep);
-    return;
-}
-
-
-#ifdef notdef
-/* CDB */
+/* CDB ?? Really needed ?? Can we get rid of it easily */
 /*
  * This is the filter routine called in nftw() callback functions.  The 
  * general rule is to return 1 if we DON'T want to unpack an inode.
@@ -1489,10 +1248,7 @@ int nftwFileFilter(char *pathname, struct stat *st, int onlySingleLink)
 	return(1);
     }
 #if	defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== nftwFileFilter(\"%s\", %p)\n", pathname, st);
+	traceFunc("== nftwFileFilter(\"%s\", %p)\n", pathname, st);
 #endif	/* PROC_TRACE || UNPACK_DEBUG */
 
     if (!S_ISREG(st->st_mode)) {
@@ -1542,158 +1298,111 @@ int nftwFileFilter(char *pathname, struct stat *st, int onlySingleLink)
 	ret = 1;
     }
 #endif /* notdef */
-    if (ret && *pathname != '/') {
-	unlinkFile(pathname);
-    }
     return(ret);
 }
-#endif
-
-
-#ifdef notdef
-/* CDB */
-void makeTempDir()
-{
-#if	defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== makeTempDir()\n");
-#endif	/* PROC_TRACE || UNPACK_DEBUG */
-    (void) strcpy(gl.tmpdir, "/tmp/pkgXXXXXX");
-    if (mkdtemp(gl.tmpdir) != gl.tmpdir) {
-	perror("mkdtemp");
-	Bail(1);
-    }
-#ifdef	UNPACK_DEBUG
-    printf("** mkdtemp() set dirname to \"%s\"\n", gl.tmpdir);
-#endif	/* UNPACK_DEBUG */
-}
-
-#endif /* notdef */
-
-
-
-void makePath(char *dirpath)	/* e.g., the command "mkdir -p" */
-{
-    char *cp = dirpath;
-
-#if	defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== makePath(%s)\n", dirpath);
-#endif	/* PROC_TRACE || UNPACK_DEBUG */
-
-    if (isDIR(dirpath)) {
-	Warn("makePath: \"%s\" exists\n", cp);
-	return;
-    }
-
-    while ((cp = strchr(cp, '/')) != NULL_STR) {
-	*cp = NULL_CHAR;
-	makeDir(dirpath);
-	*cp = '/';
-	cp++;
-    }
-    makeDir(dirpath);
-    return;
-}
-
-
-void makeDir(char *dirpath)
-{
-#if	defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== makeDir(%s)\n", dirpath);
-#endif	/* PROC_TRACE || UNPACK_DEBUG */
-
-    if (isDIR(dirpath)) {
-#if	(DEBUG > 1)
-	printf("makeDir: \"%s\" exists\n", dirpath);
-#endif	/* DEBUG > 1 */
-	return;
-    }
-    if (mkdir(dirpath, 0755) < 0) {
-	perror(dirpath);
-	Fatal("Failure in makeDir");
-    }
-    return;
-}
-
-
-void removeDir(char *dir)
-{
-
-#if	defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== removeDir(%s)\n", dir);
-#endif	/* PROC_TRACE || UNPACK_DEBUG */
-
-    if (mySystem("rm -rf %s", dir)) {
-	Fatal("Cannot clean %s", dir);
-    }
-    return;
-}
-
 
 int mySystem(const char *fmt, ...)
 {
     int ret;
     va_start(ap, fmt);
-    (void) vsprintf(gl.cmdBuf, fmt, ap);
+    (void) vsprintf(cmdBuf, fmt, ap);
     va_end(ap);
 
 #if defined(PROC_TRACE) || defined(UNPACK_DEBUG)
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== mySystem('%s')\n", gl.cmdBuf);
+	traceFunc("== mySystem('%s')\n", cmdBuf);
 #endif  /* PROC_TRACE || UNPACK_DEBUG */
 
-    ret = system(gl.cmdBuf);
+    ret = system(cmdBuf);
     if (WIFEXITED(ret)) {
 	ret = WEXITSTATUS(ret);
 #ifdef	DEBUG
 	if (ret) {
-	    Error("system(%s) returns %d", gl.cmdBuf, ret);
+	    Error("system(%s) returns %d", cmdBuf, ret);
 	}
 #endif	/* DEBUG */
     }
     else if (WIFSIGNALED(ret)) {
 	ret = WTERMSIG(ret);
-	Error("system(%s) died from signal %d", gl.cmdBuf, ret);
+	Error("system(%s) died from signal %d", cmdBuf, ret);
     }
     else if (WIFSTOPPED(ret)) {
 	ret = WSTOPSIG(ret);
-	Error("system(%s) stopped, signal %d", gl.cmdBuf, ret);
+	Error("system(%s) stopped, signal %d", cmdBuf, ret);
     }
-#if	0
-    if (ret && isFILE(UNPACK_STDERR) && (int) gl.stbuf.st_size > 0) {
-	dumpFile(stderr, UNPACK_STDERR, YES);
-    }
-#endif
     return(ret);
 }
 
 
+/*
+ * If we can tell (from examining the file text) that we created this file,
+ * then return the offset of the "real data" relative to the start of the
+ * file that contains a nomos-header...
+ */
+int iMadeThis(char *textp)
+{
+
+	char *cp, *x;
+
+/* */
+#if defined(PROC_TRACE)
+#ifdef	PROC_TRACE_SWITCH
+    if (gl.ptswitch)
+#endif	/* PROC_TRACE_SWITCH */
+	printf("== iMadeThis('%p')\n", textp);
+#endif  /* PROC_TRACE */
+/* */
+	if (strGrep(LABEL_TEXT, textp, REG_ICASE|REG_NEWLINE|REG_EXTENDED)) {
+		x = textp+cur.regm.rm_eo;
+		cp = textp+cur.regm.rm_eo;
+		if (strGrep(LABEL_ATTR, textp, REG_ICASE|REG_NEWLINE) &&
+		    strGrep(LABEL_PATH, textp, REG_ICASE) &&
+		    strGrep(LABEL_CNTS, textp, REG_ICASE)) {
+			cp = strchr(x, '\n');
+#if	0
+			Note("%s-generated link, ignore header!", gl.progName);
+			for (x = cp+1; x < cp+100; x++) {
+				printf("%c", *x);
+			}
+			printf("\n");
+			/* textp = cp+1; */
+#endif
+			return(cp-textp+1);
+		}
+	}
+	else if (strGrep(LABEL_HOTW, textp, REG_ICASE|REG_NEWLINE)) {
+		if ((cp = findEol(textp+cur.regm.rm_eo)) != NULL_STR) {
+			while (isEOL(*cp)) {
+				cp++;
+			}
+			if (strncmp(cp, "###############", 15) == 0) {
+				if ((x = findEol(cp)) != NULL_STR &&
+				    strncmp(++x, "### ", 4) == 0) {
+#if	0
+					Note("%s-generated hotword file",
+					    gl.progName);
+					/* textp += gl.regm.rm_so; */
+#endif
+					return(cur.regm.rm_so);
+				}
+			}
+		}
+	}
+	return(0);
+}
+
+
+
 int isFILE(char *pathname)
 {
 
 #ifdef	PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== isFILE(%s)\n", pathname);
+	traceFunc("== isFILE(%s)\n", pathname);
 #endif	/* PROC_TRACE */
 
     return(isINODE(pathname, S_IFREG));
 }
 
+
 /*
  * addEntry() adds a line to the specified pathname if either:
  *	(a) the line does NOT already exist in the line, or
@@ -1706,10 +1415,7 @@ int addEntry(char *pathname, int forceFlag, const char *fmt, ...)
     va_end(ap);
 
 #ifdef  PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== addEntry(%s, %d, \"%s\")\n", pathname, forceFlag, utilbuf);
+	traceFunc("== addEntry(%s, %d, \"%s\")\n", pathname, forceFlag, utilbuf);
 #endif  /* PROC_TRACE */
 
     if (pathname == NULL_STR) {
@@ -1743,10 +1449,7 @@ void Note(const char *fmt, ...)
     va_end(ap);
 
 #ifdef  PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== Warn(\"%s\")\n", utilbuf);
+	traceFunc("== Warn(\"%s\")\n", utilbuf);
 #endif  /* PROC_TRACE */
 
     (void) strcat(utilbuf, "\n");
@@ -1763,10 +1466,7 @@ void Warn(const char *fmt, ...)
     va_end(ap);
 
 #ifdef  PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== Warn(\"%s\")\n", utilbuf);
+	traceFunc("== Warn(\"%s\")\n", utilbuf);
 #endif  /* PROC_TRACE */
 
     (void) strcat(utilbuf, "\n");
@@ -1783,16 +1483,13 @@ void Assert(int fatalFlag, const char *fmt, ...)
     va_end(ap);
 
 #ifdef  PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("!! Assert(\"%s\")\n", utilbuf+strlen(gl.progName)+3);
+	traceFunc("!! Assert(\"%s\")\n", utilbuf+strlen(gl.progName)+3);
 #endif  /* PROC_TRACE */
 
     (void) strcat(utilbuf, "\n");
     Msg("%s", utilbuf);
     if (fatalFlag) {
-	Bail(1);
+	Bail(17);
     }
     return;
 }
@@ -1806,10 +1503,7 @@ void Error(const char *fmt, ...)
     va_end(ap);
 
 #ifdef  PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("== Error(\"%s\")\n");
+	traceFunc("== Error(\"%s\")\n");
 #endif  /* PROC_TRACE */
 
     (void) strcat(utilbuf, "\n");
@@ -1818,21 +1512,54 @@ void Error(const char *fmt, ...)
 }
 
 
-void Fatal(const char *fmt, ...)
-{
+void Fatal(const char *fmt, ...) {
+
     va_start(ap, fmt);
     (void) sprintf(utilbuf, "%s: FATAL: ", gl.progName);
     (void) vsprintf(utilbuf+strlen(utilbuf), fmt, ap);
     va_end(ap);
 
 #ifdef  PROC_TRACE
-#ifdef	PROC_TRACE_SWITCH
-    if (gl.ptswitch)
-#endif	/* PROC_TRACE_SWITCH */
-	printf("!! Fatal(\"%s\")\n", utilbuf+strlen(gl.progName)+9);
+	traceFunc("!! Fatal(\"%s\")\n", utilbuf + strlen(gl.progName) + 9);
 #endif  /* PROC_TRACE */
 
     (void) strcat(utilbuf, "\n");
     Msg("%s", utilbuf);
-    Bail(1);
+    freeAndClearScan(&cur);
+    Bail(18);
 }
+
+void traceFunc(char *fmtStr, ...)
+{
+    va_list args;
+
+#ifdef PROC_TRACE_SWITCH
+    if (gl.ptswitch)
+#endif /* PROC_TRACE_SWITCH */
+    va_start(args, fmtStr);
+
+    vprintf(fmtStr, args);
+    va_end(args);
+#ifdef PROC_TRACE_SWITCH
+}
+#endif /* PROC_TRACE_SWITCH */
+}
+
+
+#ifdef	MEM_DEBUG
+char *memAllocLogged(int size)
+{
+	register void *ptr;
+/* */
+	ptr = calloc(size, 1);
+	printf("%p = calloc( %d , 1 )\n", ptr, size);
+	return(ptr);
+}
+
+void memFreeLogged(void *ptr)
+{
+	printf("free( %p )\n", ptr);
+	free(ptr);
+	return;
+}
+#endif	/* MEM_DEBUG */
