@@ -27,6 +27,7 @@
 #define __USE_FILE_OFFSET64
 
 #include <stdio.h>
+#include <libgen.h>
 #include <unistd.h>
 
 #include "ununpack.h"
@@ -36,6 +37,7 @@
 #include "metahandle.h"
 #include "libfossrepo.h"
 #include "libfossdb.h"
+#include "libfossagent.h"
 
 #include <sys/timeb.h>
 
@@ -57,6 +59,7 @@ int ForceDuplicate=0;	/* when using db, should it process duplicates? */
 int PruneFiles=0;
 int SetContainerArtifact=1;	/* should initial container be an artifact? */
 FILE *ListOutFile=NULL;
+int ReunpackSwitch=0;
 
 /* for the repository */
 int UseRepository=0;
@@ -134,40 +137,6 @@ void	SafeExit	(int rc)
   exit(rc);
 } /* SafeExit() */
 
-/*********************************************************
- GetAgentKey(): Get the Agent Key from the database.
- *********************************************************/
-void	GetAgentKey	()
-{
-  int rc;
-
-  rc = MyDBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='unpack' ORDER BY agent_id DESC;");
-  if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'unpack' from the database table 'agent'\n");
-	SafeExit(1);
-	}
-  if (DBdatasize(DB) <= 0)
-      {
-      /* Not found? Add it! */
-      rc = MyDBaccess(DB,"INSERT INTO agent (agent_name,agent_rev,agent_desc) VALUES ('unpack','unknown','Recursively extract files');");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to write to the database\n");
-	printf("LOG: unable to write 'unpack' to the database table 'agent'\n");
-	SafeExit(2);
-	}
-      rc = MyDBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='unpack' ORDER BY agent_id DESC;");
-      if (rc < 0)
-	{
-	printf("ERROR: unable to access the database\n");
-	printf("LOG: unable to select 'unpack' from the database table 'agent'\n");
-	SafeExit(3);
-	}
-      }
-  Agent_pk = atoi(DBgetvalue(DB,0,0));
-} /* GetAgentKey() */
 
 /*************************************************
  InitCmd(): Initialize the metahandler CMD table.
@@ -430,22 +399,6 @@ inline int	IsDir	(char *Fname)
   return(S_ISDIR(Stat.st_mode));
 } /* IsDir() */
 
-/***************************************************
- IsFile(): Given a filename, is it a file?
- Link: should it follow symbolic links?
- Returns 1=yes, 0=no.
- (This is used by Disk extraction for getting a unique name...)
- ***************************************************/
-inline int	IsFile	(char *Fname, int Link)
-{
-  stat_t Stat;
-  int rc;
-  if (!Fname || (Fname[0]=='\0')) return(0);  /* not a directory */
-  if (Link) rc = stat64(Fname,&Stat);
-  else rc = lstat64(Fname,&Stat);
-  if (rc != 0) return(0); /* bad name */
-  return(S_ISREG(Stat.st_mode));
-} /* IsFile() */
 
 /***************************************************
  IsExe(): Check if the executable exists.
@@ -563,28 +516,6 @@ CopyFileEnd:
   return(rc);
 } /* CopyFile() */
 
-/***************************************************
- ReadLine(): Given a stream, read in one line.
- Return number of bytes read, or -1 on EOF.
- ***************************************************/
-int	ReadLine	(FILE *Fin, char *Line, int MaxLine)
-{
-  int C='@';
-  int i=0;      /* index */
-  memset(Line,0,MaxLine);
-  if (feof(Fin))        return(-1);
-  while(!feof(Fin) && (i < MaxLine-1) && (C != '\n') && (C>0))
-    {
-    C=fgetc(Fin);
-    if ((C>0) && (C!='\n'))
-      {
-      Line[i]=C;
-      i++;
-      }
-    }
-  return(i);
-} /* ReadLine() */
-
 
 /***************************************************************************/
 /***************************************************************************/
@@ -695,6 +626,7 @@ void	CheckCommands	(int Show)
 	  {
 	  case CMD_PACK:
 	  case CMD_RPM:
+	  case CMD_DEB:
 	  case CMD_ARC:
 	  case CMD_AR:
 	  case CMD_PARTITION:
@@ -821,22 +753,55 @@ int	FindCmd	(char *Filename)
   char *Type;
   char Static[256];
   int Match;
-  int i, rc;
+  int i;
+  int rc;
 
   Type = (char *)magic_file(MagicCookie,Filename);
   if (Type == NULL) return(-1);
 
+  /* Set .dsc file magic as application/x-debian-source */
+  char *pExt;
+  FILE *fp;
+  char line[500];
+  int j;
+  char c;
+  pExt = strrchr(Filename, '.');
+  if ( pExt != NULL)
+  {
+    if (strcmp(pExt, ".dsc")==0)
+    {
+      //check .dsc file contect to verify if is debian source file
+      if ((fp = fopen(Filename, "r")) == NULL){
+        printf("DEBUG: Unable to open .dsc file %s\n",Filename);
+	return(-1);
+      }
+      j=0;	
+      while ((c = fgetc(fp)) != EOF && j < 500 ){
+	line[j]=c;
+	j++; 
+      }
+      if ((strstr(line, "-----BEGIN PGP SIGNED MESSAGE-----") && strstr(line,"Source:")) || 
+	  (strstr(line, "Format:") && strstr(line, "Source:") && strstr(line, "Version:")))
+      {
+        if (Verbose > 0) {printf("First bytes of .dsc file %s\n",line);}
+        memset(Static,0,sizeof(Static));
+        strcpy(Static,"application/x-debian-source");
+        Type=Static;
+      }
+    }	
+  }
+
   /* sometimes Magic is wrong... */
   if (strstr(Type, "application/x-iso")) strcpy(Type, "application/x-iso");
 
   if (strstr(Type, "octet" ))
   {
-	rc = RunCommand("zcat","-q -l",Filename,">/dev/null 2>&1",NULL,NULL);
-	if (rc==0)
-	{
-	  memset(Static,0,sizeof(Static));
-	  strcpy(Static,"application/x-gzip");
-	  Type=Static;
+    rc = RunCommand("zcat","-q -l",Filename,">/dev/null 2>&1",NULL,NULL);
+    if (rc==0)
+    {
+      memset(Static,0,sizeof(Static));
+      strcpy(Static,"application/x-gzip");
+      Type=Static;
     }
     else  // zcat failed so try cpio (possibly from rpm2cpio)
     {
@@ -846,7 +811,34 @@ int	FindCmd	(char *Filename)
         memset(Static,0,sizeof(Static));
         strcpy(Static,"application/x-cpio");
         Type=Static;
-      }
+       }
+       else  // cpio failed so try 7zr (possibly from p7zip)
+       {
+         rc = RunCommand("7zr","x -y",Filename,">/dev/null 2>&1",NULL,NULL);
+         if (rc==0)
+         {
+           memset(Static,0,sizeof(Static));
+           strcpy(Static,"application/x-7z-compressed");
+           Type=Static;
+         }
+         else // .deb and .udeb as application/x-debian-package
+         {
+  	     if ( pExt != NULL)
+             {
+    		if ((strcmp(pExt, ".deb")==0) || (strcmp(pExt, ".udeb")==0))
+    		{
+      		  memset(Static,0,sizeof(Static));
+      		  strcpy(Static,"application/x-debian-package");
+      		  Type=Static;
+    		}
+  	     }
+	     else 
+	     {		
+           	// only here to validate other octet file types
+           	if (Verbose > 0) printf("octet mime type, file: %s\n", Filename);
+	     }
+         }
+       }
     }
   }
  
@@ -1242,13 +1234,16 @@ int	DBInsertUploadTree	(ContainerInfo *CI, int Mask)
 	free(S);
 	}
 
+// Begin add by vincent
+  if(ReunpackSwitch)
+  {
   /* Get the parent ID */
   /* Two cases -- depending on if the parent exists */
   memset(SQL,'\0',MAXSQL);
   if (CI->PI.uploadtree_pk > 0) /* This is a child */
     {
     /* Prepare to insert child */
-    snprintf(SQL,MAXSQL,"INSERT INTO uploadtree (parent,pfile_fk,ufile_mode,ufile_name,upload_fk) VALUES (%ld,%ld,%ld,'%s',%s);",
+    snprintf(SQL,MAXSQL,"INSERT INTO uploadtree (parent,pfile_fk,ufile_mode,ufile_name,upload_fk) VALUES (%ld,%ld,%ld,E'%s',%s);",
 	CI->PI.uploadtree_pk, CI->pfile_pk, CI->ufile_mode,
 	UfileName, Upload_Pk);
     rc=MyDBaccess(DBTREE,SQL); /* INSERT INTO uploadtree */
@@ -1261,13 +1256,15 @@ int	DBInsertUploadTree	(ContainerInfo *CI, int Mask)
     }
   /* Find the inserted child */
   memset(SQL,'\0',MAXSQL);
-  snprintf(SQL,MAXSQL,"SELECT uploadtree_pk FROM uploadtree WHERE upload_fk=%s AND pfile_fk=%ld AND ufile_mode=%ld AND ufile_name='%s';",
+  snprintf(SQL,MAXSQL,"SELECT uploadtree_pk FROM uploadtree WHERE upload_fk=%s AND pfile_fk=%ld AND ufile_mode=%ld AND ufile_name=E'%s';",
     Upload_Pk, CI->pfile_pk, CI->ufile_mode, UfileName);
   rc=MyDBaccess(DBTREE,"SELECT currval('uploadtree_uploadtree_pk_seq');");
   CI->uploadtree_pk = atol(DBgetvalue(DBTREE,0,0));
-  TotalItems++;
+  //TotalItems++;
   // printf("=========== AFTER ==========\n"); DebugContainerInfo(CI);
-
+  } 
+//End add by Vincent
+  TotalItems++;
   return(0);
 } /* DBInsertUploadTree() */
 
@@ -1534,6 +1531,11 @@ void	TraverseChild	(int Index, ContainerInfo *CI, char *NewDir)
 	  /* unpack a DISK: source file, FS type, and destination directory */
 	  rc=ExtractDisk(CI->Source,CMD[CI->PI.Cmd].Cmd,Queue[Index].ChildRecurse);
 	  break;
+	case CMD_DEB:
+	  /* unpack a DEBIAN source:*/
+	  rc=RunCommand(CMD[CI->PI.Cmd].Cmd,CMD[CI->PI.Cmd].CmdPre,CI->Source,
+             CMD[CI->PI.Cmd].CmdPost,CI->PartnameNew,CI->Partdir);
+	  break;
 	case CMD_DEFAULT:
 	default:
 	  /* use the original name */
@@ -1623,6 +1625,10 @@ int	Traverse	(char *Filename, char *Basename,
   strcpy(CI.Partname,CI.Source+i+1);
   strcpy(CI.PartnameNew,CI.Partname);
 
+#if 0 
+  fprintf(stderr,"TEST-> %s\n",CI.Partname);
+#endif
+ 
   /***********************************************/
   /* ignore anything that is not a directory or a file */
   /***********************************************/
@@ -1769,6 +1775,7 @@ int	Traverse	(char *Filename, char *Basename,
 		Queue[Index].PI.ChildRecurseArtifact=2;
 	  break;
 	case CMD_PACK:
+	case CMD_DEB:
 	case CMD_RPM:
 	  CI.HasChild=1;
 	  IsContainer=1;
@@ -1912,13 +1919,26 @@ TraverseEnd:
 #endif
     if (!NewDir)
       {
-      if (IsDir(CI.Source)) rmdir(CI.Source);
-      else unlink(CI.Source);
+      if (IsDir(CI.Source)) RemoveDir(CI.Source);
+//    else unlink(CI.Source);
       }
+    else RemoveDir(NewDir);
     }
   return(IsContainer);
 } /* Traverse() */
-
+/***************************************************
+ RemoveDir(char* dirpath) Remove all files under dirpath
+ ***************************************************/
+int RemoveDir(char *dirpath)
+{
+  char RMcmd[FILENAME_MAX];
+  int rc;
+  memset(RMcmd, '\0', sizeof(RMcmd));
+  strcat(RMcmd,"rm -rf ");
+  strcat(RMcmd,dirpath);
+  rc = system(RMcmd);
+  return rc;
+} /* RemoveDir() */
 /***************************************************
  TraverseStart(): Find all files (assuming a directory)
  and process all of them.
@@ -2040,6 +2060,7 @@ int	main	(int argc, char *argv[])
   int Recurse=0;
   char *ListOutName=NULL;
   char *Fname = NULL;
+  char *agent_desc = "Unpacks archives.  Also available from the command line";
 
   MagicCookie = magic_open(MAGIC_PRESERVE_ATIME|MAGIC_MIME);
   if (MagicCookie == NULL)
@@ -2079,8 +2100,10 @@ int	main	(int argc, char *argv[])
 			fprintf(stderr,"FATAL: Unable to access database\n");
 			SafeExit(20);
 			}
-		GetAgentKey();
+		GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
 		DBclose(DB);
+		if (!IsExe("dpkg-source",Quiet))
+			printf("WARNING: dpkg-source is not available on this system.  This means that debian source packages will NOT be unpacked.\n");
 		return(0);
 		break; /* never reached */
 	case 'Q':
@@ -2099,14 +2122,14 @@ int	main	(int argc, char *argv[])
 		  }
 		signal(SIGALRM,AlarmDisplay);
 		alarm(10);
-		GetAgentKey();
 		Pfile = getenv("ARG_pfile");
 		if (!Pfile) Pfile = getenv("pfile");
 		Pfile_Pk = getenv("ARG_pfile_fk");
 		if (!Pfile_Pk) Pfile_Pk = getenv("pfile_fk");
 		Upload_Pk = getenv("ARG_upload_pk");
 		if (!Upload_Pk) Upload_Pk = getenv("upload_pk");
-
+		GetAgentKey(DB, basename(argv[0]), 0, SVN_REV, agent_desc);
+	
 		/* Check for all necessary parameters */
 		if (Verbose)
 		  {
@@ -2187,7 +2210,24 @@ int	main	(int argc, char *argv[])
 	   of order.  Solution?  When using XML, only use 1 thread. */
 	MaxThread=1;
 	}
-
+  //Begin add by vincent
+  if (!ReunpackSwitch && UseRepository)
+	{
+	memset(SQL,'\0',MAXSQL);
+  	snprintf(SQL,MAXSQL,"SELECT uploadtree_pk FROM uploadtree WHERE upload_fk=%s limit 1;",Upload_Pk);
+  	int result=MyDBaccess(DB,SQL);
+  	if (result < 0)
+        	{
+        	printf("FATAL: Database access error.\n");
+        	printf("LOG: Database access error in ununpack: %s\n",SQL);
+        	SafeExit(14);
+        	}
+  	if(DBdatasize(DB) <= 0)
+  		{
+		ReunpackSwitch=1;
+		}
+	}
+  //End add by vincent
   /*** process files ***/
   for( ; optind<argc; optind++)
     {
