@@ -32,6 +32,7 @@
 #include <ctype.h>
 #include <signal.h>
 #include <grp.h>
+#include <libgen.h>
 
 #define lstat64(x,y) lstat(x,y)
 #define stat64(x,y) stat(x,y)
@@ -39,6 +40,7 @@ typedef struct stat stat_t;
 
 #include "libfossrepo.h"
 #include "libfossdb.h"
+#include "libfossagent.h"
 
 #include "../ununpack/checksum.h"
 
@@ -50,10 +52,7 @@ char BuildVersion[]="Build version: " SVN_REV ".\n";
 char SQL[MAXCMD];
 
 /* for the DB */
-void *DBMime=NULL;	/* contents of mimetype table */
-int  MaxDBMime=0;	/* how many rows in DBMime */
 void *DB;
-int Agent_pk=-1;	/* agent identifier */
 
 /* input for this system */
 long GlobalUploadKey=-1;
@@ -62,61 +61,9 @@ char GlobalURL[MAXCMD];
 int GlobalImportGold=1;	/* set to 0 to not store file in gold repository */
 gid_t ForceGroup=-1;
 
-/* for heartbeat checking */
-long	HeartbeatCount=-1;	/* used to flag heartbeats */
-long	HeartbeatCounter=-1;	/* used to count heartbeats */
-
 /* for debugging */
 int Debug=0;
 
-/**************************************************
- ShowHeartbeat(): Given an alarm signal, display a
- heartbeat.
- **************************************************/
-void    ShowHeartbeat   (int Sig)
-{
-  if ((HeartbeatCount==-1) || (HeartbeatCount != HeartbeatCounter))
-    {
-    printf("Heartbeat\n");
-    fflush(stdout);
-    }
-  /* re-schedule itself */
-  HeartbeatCounter=HeartbeatCount;
-  alarm(60);
-} /* ShowHeartbeat() */
-
-/**********************************************
- ReadLine(): Read a command from a stream.
- If the line is empty, then try again.
- Returns line length, or -1 of EOF.
- **********************************************/
-int     ReadLine (FILE *Fin, char *Line, int MaxLine)
-{
-  int C;
-  int i;
-
-  if (!Fin) return(-1);
-  memset(Line,'\0',MaxLine);
-  if (feof(Fin)) return(-1);
-  i=0;
-  C=fgetc(Fin);
-  if (C<0) return(-1);
-  while(!feof(Fin) && (C>=0) && (i<MaxLine))
-    {
-    if (C=='\n')
-        {
-        if (i > 0) return(i);
-        /* if it is a blank line, then ignore it. */
-        }
-    else
-        {
-        Line[i]=C;
-        i++;
-        }
-    C=fgetc(Fin);
-    }
-  return(i);
-} /* ReadLine() */
 
 /*********************************************************
  DBLoadGold(): Insert a file into the database and repository.
@@ -275,21 +222,6 @@ void	DBLoadGold	()
   free(Sum);
 } /* DBLoadGold() */
 
-/***************************************************
- IsFile(): Given a filename, is it a file?
- Link: should it follow symbolic links?
- Returns 1=yes, 0=no.
- ***************************************************/
-int      IsFile  (char *Fname, int Link)
-{
-  stat_t Stat;
-  int rc;
-  if (!Fname || (Fname[0]=='\0')) return(0);  /* not a directory */
-  if (Link) rc = stat64(Fname,&Stat);
-  else rc = lstat64(Fname,&Stat);
-  if (rc != 0) return(0); /* bad name */
-  return(S_ISREG(Stat.st_mode));
-} /* IsFile() */
 
 /*********************************************************
  TaintURL(): Given a URL string, taint-protect it.
@@ -382,9 +314,9 @@ int	GetURL	(char *TempFile, char *URL)
 	/* Track if a line is read.
 	   If this does not change after a minute, then heartbeat will
 	   not display. This catches cases where wget hangs. */
-	HeartbeatCounter = !HeartbeatCount;
+	InitHeartbeat();
 	}
-  HeartbeatCount = -1;
+  InitHeartbeat();
 
   rc = pclose(Fin);  /* rc is the exit status */
 
@@ -493,44 +425,6 @@ void    SetEnv  (char *S, char *TempFileDir)
 #endif
 } /* SetEnv() */
 
-/*********************************************************
- GetAgentKey(): Get the Agent Key from the database.
- *********************************************************/
-void	GetAgentKey	()
-{
-  int rc;
-
-  rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='wget_agent' ORDER BY agent_id DESC;");
-  if (rc < 0)
-	{
-	printf("ERROR upload %ld unable to access the database\n",GlobalUploadKey);
-	printf("LOG upload %ld unable to select wget_agent from the database table agent\n",GlobalUploadKey);
-	DBclose(DB);
-	exit(16);
-	}
-  if (DBdatasize(DB) <= 0)
-      {
-      /* Not found? Add it! */
-      rc = DBaccess(DB,"INSERT INTO agent (agent_name,agent_rev,agent_desc) VALUES ('wget_agent','unknown','Sets pfile wget_agent from magic or filename extension');");
-      if (rc < 0)
-	{
-	printf("ERROR upload %ld unable to write to the database\n",GlobalUploadKey);
-	printf("LOG upload %ld unable to write wget_agent to the database table agent\n",GlobalUploadKey);
-	DBclose(DB);
-	exit(17);
-	}
-      rc = DBaccess(DB,"SELECT agent_id FROM agent WHERE agent_name ='wget_agent' ORDER BY agent_id DESC;");
-      if (rc < 0)
-	{
-	printf("ERROR upload %ld unable to access the database\n",GlobalUploadKey);
-	printf("LOG upload %ld unable to select wget_agent from the database table agent\n",GlobalUploadKey);
-	DBclose(DB);
-	exit(18);
-	}
-      }
-  Agent_pk = atoi(DBgetvalue(DB,0,0));
-} /* GetAgentKey() */
-
 /***********************************************
  Usage():
  ***********************************************/
@@ -557,6 +451,7 @@ int	main	(int argc, char *argv[])
   char *TempFileDir=NULL;
   int c;
   int InitFlag=0;
+  char *agent_desc = "Network downloader.  Uses wget(1).";
 
   memset(GlobalTempFile,'\0',MAXCMD);
   memset(GlobalURL,'\0',MAXCMD);
@@ -607,7 +502,6 @@ int	main	(int argc, char *argv[])
 	fflush(stdout);
 	exit(20);
 	}
-  GetAgentKey();
 
   /* When initializing the DB, don't do anything else */
   if (InitFlag)
@@ -616,7 +510,11 @@ int	main	(int argc, char *argv[])
 	return(0);
 	}
 
+  /* Get the Agent Key from the DB */
+  GetAgentKey(DB, basename(argv[0]), GlobalUploadKey, SVN_REV, agent_desc);
+
   /* Run from the command-line (for testing) */
+  InitHeartbeat();
   signal(SIGALRM,ShowHeartbeat);
   for(arg=optind; arg < argc; arg++)
     {
@@ -628,8 +526,7 @@ int	main	(int argc, char *argv[])
     if (strstr(GlobalURL,"://"))
       {
       alarm(60);
-      HeartbeatCount=0;
-      HeartbeatCounter=-1;
+      Heartbeat(0);
       if (Debug) printf("It's a URL\n");
       if (GetURL(GlobalTempFile,GlobalURL) != 0)
 	{
@@ -638,8 +535,7 @@ int	main	(int argc, char *argv[])
 	DBclose(DB);
 	exit(21);
 	}
-      HeartbeatCount=-1;
-      HeartbeatCounter=-1;
+      InitHeartbeat();
       if (GlobalUploadKey != -1) { DBLoadGold(); }
       unlink(GlobalTempFile);
       alarm(0);
@@ -660,14 +556,13 @@ int	main	(int argc, char *argv[])
     {
     printf("OK\n"); /* inform scheduler that we are ready */
     fflush(stdout);
-    HeartbeatCount=-1;
+    InitHeartbeat();
     alarm(60);
     while(ReadLine(stdin,Parm,MAXCMD) >= 0)
       {
       if (Parm[0] != '\0')
 	{
-	HeartbeatCount=0;
-	HeartbeatCounter=-1;
+    Heartbeat(0);
 	/* 3 parameters: uploadpk downloadfile url */
 	SetEnv(Parm,TempFileDir); /* set globals */
 	if (GetURL(GlobalTempFile,GlobalURL) == 0)
