@@ -37,6 +37,7 @@ error_reporting(E_NOTICE & E_STRICT);
 global $Enotification;
 global $Email;
 global $ME;
+global $webServer;
 
 $Usage = "Usage: " . basename($argv[0]) . " [options] [archives]
   Options:
@@ -198,6 +199,7 @@ function ProcEnote($UploadPk) {
   global $Email;
   global $DB;
   global $ME;
+  global $webServer;
 
   /* get the user name from the previous upload */
   $previous = $UploadPk-1;
@@ -222,6 +224,10 @@ function ProcEnote($UploadPk) {
   $UserPk = $Users[0]['job_user_fk'];
   $UserId = $Users[0]['upload_userid'];
 
+  // need to find the jq_pk's of bucket, copyright, nomos and package 
+  // agents to use as dependencies.
+  
+  $Depends = FindDependent($UploadPk);
   /* are we being run as fossy?, either as agent or from command line */
   if($UserId === NULL && $ME == 'fossy') {
     /*
@@ -229,11 +235,11 @@ function ProcEnote($UploadPk) {
      * ensures the email address is correct, the UserName is used for the
      * salutation.
      */
-    $sched = scheduleEmailNotification($UploadPk,$UserEmail,$UserName);
+    $sched = scheduleEmailNotification($UploadPk,$webServer,$UserEmail,$UserName,$Depends);
   }
   else {
     /* run as cli, use the email passed in and $ME */
-    $sched = scheduleEmailNotification($UploadPk,$Email,$ME);
+    $sched = scheduleEmailNotification($UploadPk,$webServer,$Email,$ME,$Depends);
     print "  Scheduling email notification for $Email\n";
   }
   if ($sched !== NULL) {
@@ -272,6 +278,7 @@ function UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription,
     $match = preg_match('/^(.*?repository)/', $FilePath, $matches);
     $Filename = $matches[1] . '/' . $FilePart;
 
+
     if (empty($UploadName)) {
       $UploadName = basename($UploadArchive);
     }
@@ -391,6 +398,8 @@ function UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription,
     }
   }
     } /* UploadOne() */
+
+
     /************************************************************************/
     /************************************************************************/
     /************************************************************************/
@@ -402,6 +411,7 @@ function UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription,
     $TarExcludeList = "";
     $bucket_size = 3;
     $ME = exec('id -un',$toss,$rtn);
+
     for ($i = 1;$i < $argc;$i++) {
       switch ($argv[$i]) {
         case '-A': /* use alphabet buckets */
@@ -435,6 +445,11 @@ function UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription,
 
           break;
         case '-R': /* obsolete: recurse directories */
+        case '-W': /* webserver */
+        	$i++;
+        	$webServer = $argv[$i];
+        	//print "DBG: setting webServer to $webServer\n";
+        	break;
         case '-w': /* obsolete: URL switch to use wget */
           break;
         case '-d': /* specify upload description */
@@ -452,8 +467,6 @@ function UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription,
             exit(1);
           }
           $Enotification = TRUE;
-          if($Enotification) {
-          }
           break;
         case '-n': /* specify upload name */
           $i++;
@@ -498,7 +511,6 @@ function UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription,
               if (empty($UploadName)) {
                 $UploadName = basename($UploadArchive);
               }
-              //print "  CP2: Calling Upload1 from stdin\n";
               UploadOne($FolderPath, $UploadArchive, $UploadName, $UploadDescription);
               /* prepare for next parameter */
               $UploadName = "";
