@@ -480,6 +480,7 @@ void	DBSaveSchedulerStatus	(int Thread, char *StatusName)
 void	DBSaveJobStatus	(int Thread, int MSQid)
 {
   int JobPk=-1;
+  int RealItemsProcessed;
   long ProcessCount=0;	/* add to jq_itemsprocessed */
   time_t ElapseTime=0;	/* add to jq_elapsedtime */
   time_t ProcessTime=0;	/* add to jq_processtime */
@@ -493,24 +494,20 @@ void	DBSaveJobStatus	(int Thread, int MSQid)
   sigaddset(&Mask,SIGINT);
   sigprocmask(SIG_BLOCK,&Mask,&OldMask);
 
+  /* if false, ProcessCount is increment; if true ProcessCount is 
+     real Items processed */
+  RealItemsProcessed = 0;  
   Now = time(NULL);
   if (Thread >= 0)
 	{
-	if (!CM[Thread].IsDB) return;
-	JobPk = CM[Thread].DBJobKey;
-	if (CM[Thread].Status == ST_RUNNING)
-	  {
-	  ProcessCount = 0;
-	  CM[Thread].StatusLastDuration = Now - CM[Thread].StatusTime;
-	  CM[Thread].StatusTime = Now;
-	  }
-	else
-	  {
-	  ProcessCount = CM[Thread].ItemsProcessed;
-	  /* Don't reset values since this is only called when the job ends. */
-	  }
-	ProcessTime = CM[Thread].StatusLastDuration;
-	ElapseTime = ProcessTime;
+  	if (!CM[Thread].IsDB) return;
+    JobPk = CM[Thread].DBJobKey;
+    CM[Thread].StatusLastDuration = Now - CM[Thread].StatusTime;
+    CM[Thread].StatusTime = Now;
+    ProcessCount = CM[Thread].ItemsProcessed;
+    RealItemsProcessed = 1;  
+  	ProcessTime = CM[Thread].StatusLastDuration;
+    ElapseTime = ProcessTime;
 	}
   else if (MSQid >= 0)
 	{
@@ -554,23 +551,17 @@ void	DBSaveJobStatus	(int Thread, int MSQid)
   if (JobPk != -1)	/* ignore non-jobs */
     {
     char SQL[MAXCMD];
-#if 0
-    if (Thread!=-1)
-	{
-	printf("To update[%d,%d]: jq_pk=%d  count=%ld  elapse=%d  processtime=%d\n",
-		Thread,MSQid,JobPk,
-		ProcessCount,(int)ElapseTime,(int)ProcessTime);
-	}
-    else
-	{
-	printf("To update[%d,%d] [%d/%d]: jq_pk=%d  count=%ld  elapse=%d  processtime=%d\n",
-		Thread,MSQid,MSQ[MSQid].ItemsDone,MSQ[MSQid].MaxItems,JobPk,
-		ProcessCount,(int)ElapseTime,(int)ProcessTime);
-	}
-#endif
     memset(SQL,'\0',MAXCMD);
-    snprintf(SQL,MAXCMD,"UPDATE jobqueue SET jq_itemsprocessed=jq_itemsprocessed+%ld, jq_elapsedtime=jq_elapsedtime+%d, jq_processedtime=jq_processedtime+%d WHERE jq_pk=%d;",
-	ProcessCount,(int)ElapseTime,(int)ProcessTime,JobPk);
+    if (RealItemsProcessed)
+    {
+      snprintf(SQL,MAXCMD,"UPDATE jobqueue SET jq_itemsprocessed=%ld, jq_elapsedtime=jq_elapsedtime+%d, jq_processedtime=jq_processedtime+%d WHERE jq_pk=%d;",
+	            ProcessCount,(int)ElapseTime,(int)ProcessTime,JobPk);
+    }
+    else
+    {
+      snprintf(SQL,MAXCMD,"UPDATE jobqueue SET jq_itemsprocessed=jq_itemsprocessed+%ld, jq_elapsedtime=jq_elapsedtime+%d, jq_processedtime=jq_processedtime+%d WHERE jq_pk=%d;",
+	            ProcessCount,(int)ElapseTime,(int)ProcessTime,JobPk);
+    }
     if (DBLockAccess(DB,SQL) < 0)
 	{
 	LogPrint("FATAL: Scheduler failed to update job status in DB.\n");
