@@ -22,7 +22,7 @@
  * extend this class.
  *
  * @package FOSSologyTest
- * @version "$Id: fossologyTestCase.php 2107 2009-05-05 04:33:05Z rrando $"
+ * @version "$Id: fossologyTestCase.php 2472 2009-08-24 19:35:52Z rrando $"
  *
  * Created on Sep 1, 2008
  */
@@ -71,21 +71,22 @@ class fossologyTestCase extends fossologyTest
     if(empty($UserName)) {
       return("No User Name, cannot add user");
     }
-    $page = $this->mybrowser->get($URL);
-    $page = $this->mybrowser->clickLink('Add');
-    $this->assertTrue($this->myassertText($page, '/Add A User/'),
-      "Did NOT find Title, 'Add A User'");
+
+    //$page = $this->mybrowser->get($URL);
+    //$page = $this->mybrowser->clickLink('Add');
+    //$this->assertTrue($this->myassertText($page, '/Add A User/'),
+    //  "Did NOT find Title, 'Add A User'");
     $this->setUserFields($UserName,$Description, $Email, $Access, $Folder,
     NULL,NULL, $Password, $EmailNotify);
 
     /* fields set, add the user */
     $page = $this->mybrowser->clickSubmit('Add!',"Could not select the Add! button");
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     //print "<pre>page after clicking Add!\n"; print_r($page) . "\n</pre>";
-    if($this->myassertText($page, "/User added/")) {
+    if($this->myassertText($page, "/User .*? added/")) {
       return(NULL);
     }
-    elseif($this->myassertText($page, "/User already exists\.  Not added/")) {
+    else if($this->myassertText($page, "/User already exists\.  Not added/")) {
       return('User already exists.  Not added');
     }
     return(NULL);
@@ -121,10 +122,16 @@ class fossologyTestCase extends fossologyTest
       return(NULL);
     }
     //print "Got back from getMailSubjects:\n";print_r($headers) . "\n";
-    /* check for errors */
+
+    /*
+       check for errors
+     */
+    /**
+     * @TODO use exceptions here, so you can indicated the correct item.
+     */
     if(preg_match('/ERROR/',$headers[0],$matches)) {
       $this->fail("{$headers[0]}\n");
-      return($headers);
+      return(FALSE);
     }
     $pattern = 'completed with no errors';
 
@@ -169,12 +176,14 @@ class fossologyTestCase extends fossologyTest
 
     /* Need to check parameters */
     if (is_null($parent)) {
-      $parent = 1; // default is root folder
+      $FolderId = 1; // default is root folder
     }
     if (is_null($description)) {   // set default if null
       $description = "Folder $name created by createFolder as subfolder of $parent";
     }
     $page = $this->mybrowser->get($URL);
+    // There is only 1 create menu, so just select it
+    // No need to make sure we are in folders menu.
     $page = $this->mybrowser->clickLink('Create');
     $this->assertTrue($this->myassertText($page, '/Create a new Fossology folder/'));
     /* if $FolderId=0 select the folder to create this folder under */
@@ -185,7 +194,7 @@ class fossologyTestCase extends fossologyTest
     $this->assertTrue($this->mybrowser->setField('newname', $name));
     $this->assertTrue($this->mybrowser->setField('description', "$description"));
     $page = $this->mybrowser->clickSubmit('Create!');
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     if($this->myassertText($page, "/Folder $name Created/")) {
       return(NULL);
     }
@@ -193,7 +202,7 @@ class fossologyTestCase extends fossologyTest
       return("Folder $name Exists");
     }
     else {
-      $this->fail('Failure! Unknown Error when creating folder $name\n');
+      $this->fail("Failure! Unknown Error when creating folder $name\n");
     }
   }
 
@@ -225,7 +234,7 @@ class fossologyTestCase extends fossologyTest
     }
     $this->assertTrue($this->mybrowser->setField('folder', $FolderId));
     $page = $this->mybrowser->clickSubmit('Delete!');
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     $this->assertTrue($this->myassertText($page, "/Deletion of folder $folder added to job queue/"),
      "delete Folder Failed!\nPhrase 'Deletion of folder $folder added to job queue' not found\n");
   }
@@ -258,7 +267,7 @@ class fossologyTestCase extends fossologyTest
     }
     $this->assertTrue($this->mybrowser->setField('upload', $UploadId));
     $page = $this->mybrowser->clickSubmit('Delete!');
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     $this->assertTrue($this->myassertText($page, "/Deletion added to job queue/"),
      "delete Upload Failed!\nPhrase 'Deletion added to job queue' not found\n");
   }
@@ -276,7 +285,7 @@ class fossologyTestCase extends fossologyTest
     if(empty($User)) {
       return('No User Specified');
     }
-    $this->Login();
+    // Should already be logged in... no need to call this: $this->Login();
     $page = $this->mybrowser->get("$URL?mod=user_del");
     /* Get the user id */
     $select = $this->parseSelectStmnt($page, 'userid',$User);
@@ -285,7 +294,7 @@ class fossologyTestCase extends fossologyTest
       $this->assertTrue($this->mybrowser->setField('confirm', 1));
       $page = $this->mybrowser->clickSubmit('Delete!',
         "Could not select the Delete! button");
-      $this->assertTrue(page);
+      $this->assertTrue($page);
       if($this->myassertText($page, "/User deleted/")) {
         print "User $User Deleted\n";
         $this->pass();
@@ -330,7 +339,7 @@ class fossologyTestCase extends fossologyTest
     }
     $this->assertTrue($this->mybrowser->setField('newdesc', "$description"));
     $page = $this->mybrowser->clickSubmit('Edit!');
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     $this->assertTrue($this->myassertText($page, "/Folder Properties changed/"), "editFolder Failed!\nPhrase 'Folder Properties changed' not found\n");
   }
   /**
@@ -370,7 +379,7 @@ class fossologyTestCase extends fossologyTest
 
     /* fields set, edit the user */
     $page = $this->mybrowser->clickSubmit('Edit!',"Could not select the Edit! button");
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     //print "<pre>page after clicking Add!\n"; print_r($page) . "\n</pre>";
     if($this->myassertText($page, "/User edited/")) {
       return(NULL);
@@ -424,7 +433,7 @@ class fossologyTestCase extends fossologyTest
     $destFolderId = $this->getFolderId($destFolder, $page, 'targetfolderid');
     $this->assertTrue($this->mybrowser->setField('targetfolderid', $destFolderId));
     $page = $this->mybrowser->clickSubmit('Move!');
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     print "page after move is:\n$page\n";
     $this->assertTrue($this->myassertText($page,
     //"/Moved $upload from folder $oldFolder to folder $destFolder/"),
@@ -465,7 +474,7 @@ class fossologyTestCase extends fossologyTest
     }
     $this->assertTrue($this->mybrowser->setField('targetfolderid', $DfolderId));
     $page = $this->mybrowser->clickSubmit('Move!');
-    $this->assertTrue(page);
+    $this->assertTrue($page);
     $this->assertTrue($this->myassertText($page, "/Moved folder $folder to folder $destination/"),
         "moveFolder Failed!\nPhrase 'Move folder $folder to folder ....' not found\n");
   }
@@ -487,18 +496,44 @@ class fossologyTestCase extends fossologyTest
    */
   protected function setUserFields($UserName=NULL, $Description=NULL, $Email=NULL,
   $Access=1, $Folder=1, $Block=NULL, $Blank=NULL,
-  $Password=NULL, $EmailNotify='y'){
+  $Password=NULL, $EmailNotify=NULL){
 
     $FailStrings = NULL;
 
-    /*
-     print "SUF: parameters are:\n";
-     print "SUF: user name:$UserName\n";
-     print "SUF: desc:$Description\n";
-     print "SUF: email:$Email\n";
-     print "SUF: access:$Access\n";
-     print "SUF: folder:$Folder\n";
-     */
+    global $URL;
+
+    if(strtoupper($UserName) == 'NULL') {
+      $this->fail("setUserFields, FATAL! no user name to set\n");
+    }
+    if(strtoupper($Description) == 'NULL') {
+      $Description = '';
+    }
+    if(strtoupper($Email) == 'NULL') {
+      $Email = '';
+    }
+    if(strtoupper($Access) == 'NULL') {
+      $Access = 1;
+    }
+    if(strtoupper($Folder) == 'NULL') {
+      $Folder = 1;
+    }
+    if(strtoupper($Block) == 'NULL') {
+      $Block = '';
+    }
+    if(strtoupper($Blank) == 'NULL') {
+      $Blank = '';
+    }
+    if(strtoupper($Password) == 'NULL') {
+      $Password = '';
+    }
+    if(strtoupper($EmailNotify) == 'NULL'|| is_null($EmailNotify)) {
+      unset($EmailNotify);
+    }
+
+    $page = $this->mybrowser->get($URL);
+    $page = $this->mybrowser->clickLink('Add');
+    $this->assertTrue($this->myassertText($page, '/Add A User/'),
+      "Did NOT find Title, 'Add A User'");
 
     if(!empty($UserName)) {
       $this->assertTrue($this->mybrowser->setField('username', $UserName),
@@ -537,8 +572,12 @@ class fossologyTestCase extends fossologyTest
       $this->assertTrue($this->mybrowser->setField('pass2', $Password),
       "Could Not set the pass2 field");
     }
-    if(!empty($EmailNotifiy)) {
-      $this->assertTrue($this->mybrowser->setField('enote', $EmailNotify),
+    if(isset($EmailNotify)) {
+      $this->assertTrue($this->mybrowser->setField('enote', TRUE),
+      "Could Not set the enote Field to non default value");
+    }
+    else {
+      $this->assertTrue($this->mybrowser->setField('enote', FALSE),
       "Could Not set the enote Field");
     }
     return(NULL);
@@ -613,30 +652,30 @@ class fossologyTestCase extends fossologyTest
       $this->setAgents($agents);
     }
     $page = $this->mybrowser->clickSubmit('Upload!');
-    $this->assertTrue(page);
-    $this->assertTrue($this->myassertText($page, '/Upload added to job queue/'),
-      "FAILURE:Did not find the message 'Upload added to job queue'\n");
-  }
+    $this->assertTrue($page);
+    $this->assertTrue($this->myassertText($page, '/The file .*? has been uploaded/'),
+      "FAILURE:Did not find the message 'The file .*? has been uploaded'\n");
+  } // uploadFile
   /**
-   * uploadServer
-   * ($parentFolder,$uploadPath,$description=null,$uploadName=null,$agents=null)
-   *
-   * Upload a file and optionally schedule the agents.  The web-site must
-   * already be logged into before using this method.
-   *
-   * @param string $parentFolder the parent folder name, default is root
-   * folder (1)
-   * @param string $uploadPath the path to upload data, can be a file or directory
-   * @param string $description a default description is always used. It
-   * can be overridden by supplying a description.
-   * @param string $uploadName=null optional upload name
-   * @param string $agents=null agents to schedule
-   *
-   * @return pass or fail
-   *
-   * @TODO determine if setting alpha folders is worth it.  Right now this routine
-   * does not use them.....
-   */
+  * uploadServer
+  * ($parentFolder,$uploadPath,$description=null,$uploadName=null,$agents=null)
+  *
+  * Upload a file and optionally schedule the agents.  The web-site must
+  * already be logged into before using this method.
+  *
+  * @param string $parentFolder the parent folder name, default is root
+  * folder (1)
+  * @param string $uploadPath the path to upload data, can be a file or directory
+  * @param string $description a default description is always used. It
+  * can be overridden by supplying a description.
+  * @param string $uploadName=null optional upload name
+  * @param string $agents=null agents to schedule
+  *
+  * @return pass or fail
+  *
+  * @TODO determine if setting alpha folders is worth it.  Right now this routine
+  * does not use them.....
+  */
   public function uploadServer($parentFolder = 1, $uploadPath, $description = null,
   $uploadName = null, $agents = null)
   {
@@ -693,8 +732,9 @@ class fossologyTestCase extends fossologyTest
       $this->fail("FAIL: could not set agents in uploadServer test\n");
     }
     $page = $this->mybrowser->clickSubmit('Upload!');
-    $this->assertTrue(page);
-    $this->assertTrue($this->myassertText($page, '/Upload jobs for .*? added to job queue/'));
+    $this->assertTrue($page);
+    $this->assertTrue($this->myassertText($page, '/The upload for .*? has been scheduled/'),
+      "FAIL! did not see phrase The upload for .*? has been scheduled\n");
     //print  "************ page after Upload! *************\n$page\n";
   } //uploadServer
 
@@ -761,19 +801,20 @@ class fossologyTestCase extends fossologyTest
     $this->assertTrue($this->mybrowser->setField('geturl', $url));
     $this->assertTrue($this->mybrowser->setField('description', "$description"));
     /* Set the name field if an upload name was passed in. */
-    if (!(is_null($upload_name)))
+    if (!(is_null($uploadName)))
     {
       $this->assertTrue($this->mybrowser->setField('name', $url));
     }
-    /* selects agents 1,2,3 license, mime, pkgmetagetta */
+    /* selects agents using numbers 1,2,3 or names license, mime, pkgmetagetta */
     $rtn = $this->setAgents($agents);
     if (!is_null($rtn))
     {
       $this->fail("FAIL: could not set agents in uploadAFILE test\n");
     }
     $page = $this->mybrowser->clickSubmit('Upload!');
-    $this->assertTrue(page);
-    $this->assertTrue($this->myassertText($page, '/Upload added to job queue/'));
+    $this->assertTrue($page);
+    $this->assertTrue($this->myassertText($page, '/The upload .*? has been scheduled/'),
+      "FAIL! did find phrase The upload .*? has been scheduled\n");
     //print  "************ page after Upload! *************\n$page\n";
   } //uploadUrl
 
@@ -787,7 +828,7 @@ class fossologyTestCase extends fossologyTest
    *
    * @return boolean TRUE/FALSE
    *
-   * @version "$Id: fossologyTestCase.php 2107 2009-05-05 04:33:05Z rrando $"
+   * @version "$Id: fossologyTestCase.php 2472 2009-08-24 19:35:52Z rrando $"
    *
    * @TODO: make a general program that can wait an arbitrary time, should
    * also allow for an interval, e.g. check for 2 hours every 7 min.
