@@ -15,31 +15,42 @@
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ***********************************************************/
-/*************************************************
+/**
+ * common-job
+ * \brief library of functions used by the ui to manage 'jobs'
+ * 
+ * @version "$Id: $"
+ */
+/*
  Restrict usage: Every PHP file should have this
  at the very beginning.
  This prevents hacking attempts.
- *************************************************/
+ */
 global $GlobalReady;
 if (!isset($GlobalReady)) {
   exit;
 }
-/************************************************************
+
+/*
  Terminology:
  Scheduled jobs are divided into a specific heirarchy.
+ 
  "Job"
  This is the highest level and assigns a name to the class of
  tasks that need to be performed.
+ 
  "JobQueue"
  Each job may require multiple "JobQueue" tasks.
  JobQueue tasks may have dependencies upon the completion of
  other JobQueue tasks.
+ 
  "Tasks"
  A single JobQueue items may define hundreds of individual operations.
  The scheduler handles the splitting of JobQueue items into tasks
  for processing.
  The Task may be a single operation, or a multi-SQL query (MSQ).
  (See the documentation for managing the jobqueue for the scheduler.
+ 
  As an example:
  The "license" job requires three jobqueue items:
  - Filter_License: For each file, pre-process the file contents.
@@ -55,7 +66,8 @@ if (!isset($GlobalReady)) {
 
  The jobqueue tasks for a specific job may vary based on the
  item being processed.
- ************************************************************/
+ */
+
 /*
  * funcion: JobSetPriority
  *
@@ -195,15 +207,19 @@ function JobQueueAddDependency($JobQueueChild, $JobQueueParent) {
 /**
  * function:  JobAddUpload
  *
- * @abstract Insert a new upload record.
+ * Insert a new upload record, and update foldercontents table
  *
  * @param string $job_name   the name to associate with the job
+ * NOTE: $job_name is not used in this function!
  * @param string $filename   the path the to file to upload
  * @param string $desc       A meaningful description
  * @param int    $UploadMode e.g. 1<<2 = URL, 1<<3 = file upload, 1<<4 = filesystem
  * @param int    $FolderPk   The folder primary key
  *
  * @return upload_pk the upload primary key or null (failure)
+ *
+ * @todo fix the name of this function, it has nothing to do with scheduling
+ * a job.
  */
 function JobAddUpload($job_name, $filename, $desc, $UploadMode, $FolderPk) {
   global $DB;
@@ -224,19 +240,20 @@ function JobAddUpload($job_name, $filename, $desc, $UploadMode, $FolderPk) {
   $UserId = $_SESSION['UserId'];
   if (!empty($UserId)) {
     $DB->Action("INSERT INTO upload
-      (upload_desc,upload_filename,upload_userid,upload_mode) VALUES
-      ('$desc','$filename','$UserId','$UploadMode');");
+      (upload_desc,upload_filename,upload_userid,upload_mode,upload_origin) VALUES
+      ('$desc','$job_name','$UserId','$UploadMode','$filename');");
     $Results = $DB->Action("SELECT currval('upload_upload_pk_seq') as upload_pk FROM upload;");
     $uploadpk = $Results[0]['upload_pk'];
     if (empty($uploadpk)) {
       $DB->Action("ROLLBACK");
       return;
     }
-  } else {
+  }
+  else {
     /* Create the upload record WITHOUT upload_userid */
     $DB->Action("INSERT INTO upload
-      (upload_desc,upload_filename,upload_mode) VALUES
-      ('$desc','$filename','$UploadMode');");
+      (upload_desc,upload_filename,upload_mode,upload_origin) VALUES
+      ('$desc','$job_name','$UploadMode','$filename');");
     $Results = $DB->Action("SELECT currval('upload_upload_pk_seq') as upload_pk FROM upload;");
     $uploadpk = $Results[0]['upload_pk'];
     if (empty($uploadpk)) {
@@ -266,6 +283,7 @@ function JobAddUpload($job_name, $filename, $desc, $UploadMode, $FolderPk) {
   $DB->Action("COMMIT;");
   return ($uploadpk);
 } // JobAddUpload()
+
 /************************************************************
  JobQueueFindKey(): Given a job_pk and a jobqueue name, returns
  the jq_pk, or -1 if it does not exist.
@@ -304,13 +322,15 @@ function JobFindKey($UploadPk, $JobName) {
     $SQL = "SELECT job_pk FROM job WHERE job_upload_fk = '$UploadPk' AND job_name = '$JobName';";
   }
   $Results = $DB->Action($SQL);
-  $jobpk = $Results[0]['job_pk'];
-  if (!empty($jobpk)) {
-    return ($jobpk);
+  if(empty($Results)) {
+    return(-1);
+  }
+  else {
+    return($Results[0]['job_pk']);
   }
-  return (-1);
 } // JobFindKey()
 
+
 /**
  * function: JobAddJob
  *
@@ -338,29 +358,33 @@ function JobAddJob($upload_pk, $job_name, $priority = 0) {
     $job_user_fk = $Results[0]['user_pk'];
   }
 
-if (!empty($_SESSION['UserEmail'])) {
-  $job_email_notify = $_SESSION['UserEmail'];
-} else {
-  $job_email_notify = 'fossy@localhost';
-}
-$Job_email_notify = str_replace("'", "''", $job_email_notify);
-$Job_name = str_replace("'", "''", $job_name);
-if (empty($upload_pk)) {
-  $SQLInsert = "INSERT INTO job
+  if (!empty($_SESSION['UserEmail'])) {
+    $job_email_notify = $_SESSION['UserEmail'];
+  } else {
+    $job_email_notify = 'fossy@localhost';
+  }
+  $Job_email_notify = str_replace("'", "''", $job_email_notify);
+  $Job_name = str_replace("'", "''", $job_name);
+  if (empty($upload_pk)) {
+    $SQLInsert = "INSERT INTO job
     	(job_user_fk,job_queued,job_priority,job_email_notify,job_name) VALUES
     	('$job_user_fk',now(),'$priority','$Job_email_notify','$Job_name');";
-} else {
-  $SQLInsert = "INSERT INTO job
+  }
+  else {
+    $SQLInsert = "INSERT INTO job
     	(job_user_fk,job_queued,job_priority,job_email_notify,job_name,job_upload_fk) VALUES
      	('$job_user_fk',now(),'$priority','$Job_email_notify','$Job_name','$upload_pk');";
-}
-$jobpk = JobFindKey($upload_pk, $job_name);
-if ($jobpk >= 0) {
+  }
+  $jobpk = JobFindKey($upload_pk, $Job_name);
+  /*
+     If the job already exists, just return the jobpk, don't insert
+   */
+  if ($jobpk >= 0) {
+    return ($jobpk);
+  }
+  $DB->Action($SQLInsert);
+  $jobpk = JobFindKey($upload_pk, $job_name);
   return ($jobpk);
-}
-$DB->Action($SQLInsert);
-$jobpk = JobFindKey($upload_pk, $job_name);
-return ($jobpk);
 } // JobAddJob()
 
 /**
@@ -404,8 +428,10 @@ function JobQueueAdd($job_pk, $jq_type, $jq_args, $jq_repeat, $jq_runonpfile, $D
   /* Check if the job exists */
   $Results = $DB->Action("SELECT jq_pk FROM jobqueue
   	WHERE jq_job_fk = '$job_pk' AND jq_type = '$jq_type' AND jq_args = '$jq_args';");
-  $jqpk = $Results[0]['jq_pk'];
-  if (empty($jqpk)) {
+  if (!empty($Results)) {
+    $jqpk = $Results[0]['jq_pk'];
+  }
+  else if (empty($Results)) {
     /* Add the job */
     $SQL = "INSERT INTO jobqueue ";
     $SQL.= "(jq_job_fk,jq_type,jq_args,jq_repeat,jq_runonpfile,jq_starttime,jq_endtime,jq_end_bits) VALUES ";
@@ -594,6 +620,7 @@ function JobListSummary($upload_pk) {
   $Status = array();
   $Status['total'] = 0;
   $Status['completed'] = 0;
+  $Status['pending'] = 0;
   $Status['active'] = 0;
   $Status['failed'] = 0;
   $SQL = "SELECT job_pk,jq_starttime,jq_endtime,jq_end_bits FROM jobqueue
@@ -601,6 +628,7 @@ function JobListSummary($upload_pk) {
   	AND job_upload_fk = '$upload_pk'
   	ORDER BY job_pk;";
   $Results = $DB->Action($SQL);
+  if (empty($Results)) return $Status;
   /* Scan and track the results */
   $JobId = $Results[0]['job_pk'];
   $i = 0;
@@ -618,7 +646,11 @@ function JobListSummary($upload_pk) {
     } else {
       $State|= 0x04;
     }
-    $i++;
+    if(count($Results) >= 1) {
+      $i++;
+    }
+    if (array_key_exists($i, $Results) && array_key_exists('job_pk',$Results[$i]))
+    {
     if ($Results[$i]['job_pk'] != $JobId) {
       $Status['total']++;
       if ($State & 0x01) {
@@ -633,6 +665,7 @@ function JobListSummary($upload_pk) {
       $State = 0;
       $JobId = $Results[$i]['job_pk'];
     }
+    }
   }
   return ($Status);
 } // JobListSummary()
