@@ -54,13 +54,12 @@ class licgroup extends FO_Plugin
       {
       if (GetParm("mod",PARM_TEXT) == $this->Name)
 	{
-	menu_insert("Browse::License Groups",1);
-	menu_insert("Browse::[BREAK]",100);
-	menu_insert("Browse::Clear",101,NULL,NULL,"<a title='Clear highlighting' href='javascript:LicColor(\"\",\"\",\"\",\"\");'>Clear</a>");
+	menu_insert("Browse::License Groups",-5);	
+	menu_insert("Browse::Clear",-2,NULL,NULL,NULL,"<a title='Clear highlighting' href='javascript:LicColor(\"\",\"\",\"\",\"\");'>Clear</a>");
 	}
       else
 	{
-	menu_insert("Browse::License Groups",1,$URI,"View license group histogram");
+	menu_insert("Browse::License Groups",-5,$URI,"View license group histogram");
 	}
       }
   } // RegisterMenus()
@@ -723,7 +722,7 @@ class licgroup extends FO_Plugin
 	break;
       case "HTML":
 	$V .= "<font class='text'>\n";
-	$V .= "<center><b><font color='red'>WARNING: This functionality is a work in progress and is currently incomplete.</font></b></center><P>\n";
+	$V .= "<center><b><font color='red'>WARNING: Licence groups only work for the bsam license scanner and do not use the results from licterm.  This functionality has been superceded in v 1.2 by 'buckets' based on the nomos license scanner.</font></b></center><P>\n";
 
 	/************************/
 	/* Show the folder path */
