@@ -44,7 +44,7 @@ class licterm_manage extends FO_Plugin
   var $Version    = "1.0";
   var $Dependency = array("db");
   var $DBaccess   = PLUGIN_DB_ANALYZE;
-  var $MenuList   = "Organize::License::Manage Terms";
+  var $MenuList   = "Obsolete::License::Manage Terms";
   var $LoginFlag  = 0;
 
   /***********************************************************
@@ -552,7 +552,10 @@ function moveOptions(theSelFrom, theSelTo)
       $SQL = "SELECT * FROM licterm WHERE licterm_name = '$TermName';";
       }
     $Results = $DB->Action($SQL);
+    /* turn off E_NOTICE so this stops reporting undefined offset */
+    $errlev = error_reporting(E_ERROR | E_WARNING | E_PARSE);
     $TermKey = $Results[0]['licterm_pk'];
+    error_reporting($errlev); /* return to previous error reporting level */	
 
     /* Do the insert (or update) */
     if (empty($TermKey))
@@ -679,11 +682,11 @@ function moveOptions(theSelFrom, theSelTo)
           if (empty($rc))
             {
             /* Need to refresh the screen */
-            $V .= PopupAlert('License term information updated.');
+            $V .= displayMessage('License term information updated.');
             }
           else
             {
-            $V .= PopupAlert($rc);
+            $V .= displayMessage("Could not add License term information, error code is:$rc");
             }
           }
         $TermKey = GetParm('termkey',PARM_INTEGER);
@@ -703,5 +706,4 @@ function moveOptions(theSelFrom, theSelTo)
 
   };
 $NewPlugin = new licterm_manage;
-$NewPlugin->Initialize();
 ?>
