@@ -193,7 +193,7 @@ class ui_view extends FO_Plugin
   /***********************************************************
    GetHighlightMenu(): If there is a highlight menu, create it.
    ***********************************************************/
-  function GetHighlightMenu($PageBlockSize)
+  function GetHighlightMenu($PageBlockSize, $ViewOnly=False)
     {
     if (empty($this->Highlight)) { return; }
     $First=1;
@@ -206,13 +206,20 @@ class ui_view extends FO_Plugin
 	if ($First)
 	  {
 	  $First = 0;
-	  $V .= "<tr><th>Match</th>";
-	  $V .= "<th></th><th></th>";
-	  $V .= "<th align='left'>Item</th>";
-	  $V .= "</tr>\n";
+      if (!$ViewOnly) 
+      {
+	    $V .= "<tr>";
+        $V .= "<th>Match</th>";
+	    $V .= "<th></th>";
+	    $V .= "<th></th>";
+        if (!$ViewOnly) $V .= "<th align='left'>Item</th>";
+	    $V .= "</tr>\n";
+      }
 	  }
-	$V .= "<tr bgcolor='" . $this->HighlightColors[$H['Color']] . "'>\n";
-	$V .= "<td align='right'>" . $H['Match'] . "</td>\n";
+    if (key_exists('Color', $this->HighlightColors))
+      $V .= "<tr bgcolor='" . $this->HighlightColors[$H['Color']] . "'>\n";
+
+    if (!$ViewOnly) $V .= "<td align='right'>" . $H['Match'] . "</td>\n";
 
 	$V .= "<td>";
 	if ($PageBlockSize > 0)
@@ -226,15 +233,24 @@ class ui_view extends FO_Plugin
 	  }
 	$V .= "</td>\n";
 
-	$V .= "<td>";
-	if (!empty($H['RefURL']))
-		{
-		// $V .= "<a href='" . $H['RefURL'] . "' target='_blank'>ref</a>";
-		$V .= "<a href='javascript:;' onClick=\"javascript:window.open('" . $H['RefURL'] . "','License','width=600,height=400,toolbar=no,scrollbars=yes,resizable=yes');\">ref</a>";
-		}
-	$V .= "</td>\n";
+    if (!$ViewOnly)
+    {
+      $V .= "<td>";
+      if (!empty($H['RefURL']))
+      {
+        $V .= "<a href='javascript:;' onClick=\"javascript:window.open('" . $H['RefURL'] . "','License','width=600,height=400,toolbar=no,scrollbars=yes,resizable=yes');\">ref</a>";
+      }
+      $V .= "</td>\n";
+    }
 
-	$V .= "<td>" . $H['Name'] . "</td>\n";
+    /* strip out characters we don't want to see */
+    $S = strip_tags($H['Name']);
+    $S = str_replace(chr(0xc2),"",$S);  // comes from utf-8 copyright symbol
+	$S = str_replace("&Acirc;","",$S);  // comes from utf-8 copyright symbol
+	$S = str_replace("\r","",$S);
+	$S = str_replace("\n","",$S);
+	$S = str_replace("\t","&nbsp;&nbsp;",$S);
+	$V .= "<td>" . $S . "</td>\n";
 	$V .= "</tr>\n";
 	}
       }
@@ -382,15 +398,20 @@ class ui_view extends FO_Plugin
     $ReadCount = strlen($S);
     while(($ReadCount > 0) && ($Length > 0))
       {
-      /* Massage the data and print it */
-      $S = preg_replace('/[^[:print:][:space:]]+/'," ",$S);
-      $S = htmlentities($S);
       if ($Flowed)
 	{
 	$S = str_replace("\r","",$S);
-	$S = str_replace("\n","<br>\n",$S);
 	$S = str_replace("\t","&nbsp;&nbsp;",$S);
+	$S = str_replace("<","&lt;",$S);
+	$S = str_replace(">","&gt;",$S);
+	$S = str_replace("\n","<br>\n",$S);
 	}
+    else
+    {
+      /* Massage the data and print it */
+      $S = preg_replace('/[^[:print:][:space:]]+/'," ",$S);
+      $S = htmlentities($S);
+    }
 
       if (($this->FindHighlight($Start)) & 0x01)
 	{
@@ -594,7 +615,7 @@ class ui_view extends FO_Plugin
    This function is intended to be called from other plugins.
    ***********************************************************/
   function ShowView($Fin=NULL, $BackMod="browse",
-		    $ShowMenu=1, $ShowHeader=1, $ShowText=NULL)
+		    $ShowMenu=1, $ShowHeader=1, $ShowText=NULL, $ViewOnly=False)
     {
     if ($this->State != PLUGIN_STATE_READY) { return; }
     $V="";
@@ -603,7 +624,9 @@ class ui_view extends FO_Plugin
     $Folder = GetParm("folder",PARM_INTEGER);
     $Show = GetParm("show",PARM_STRING);
     $Item = GetParm("item",PARM_INTEGER);
+    $nomosagent_pk = GetParm("napk",PARM_INTEGER);
     $Page = GetParm("page",PARM_INTEGER);
+    $bucketagent_pk = GetParm("bapk",PARM_INTEGER);
     if (!$Fin && (empty($Item) || empty($Upload))) { return; }
     if (empty($Page)) { $Page=0; };
 
@@ -614,33 +637,34 @@ class ui_view extends FO_Plugin
 	case 'flow':	$Format='flow'; break;
 	default:
 	  /* Determine default show based on mime type */
-	  $Meta = GetMimeType($Item);
-	  list($Type,$Junk) = split("/",$Meta,2);
-	  if ($Type == 'text') { $Format = 'flow'; }
-	  else switch($Meta)
-	  	{
-		case "application/octet-string":
-		case "application/x-awk":
-		case "application/x-csh":
-		case "application/x-javascript":
-		case "application/x-perl":
-		case "application/x-shellscript":
-		case "application/x-rpm-spec":
-		case "application/xml":
-		case "message/rfc822":
-			$Format='flow';
-			break;
-		default:
-			$Format = 'flow';
+      if (empty($Item))
+        $Format = 'text';
+      else
+      {
+        $Meta = GetMimeType($Item);
+        list($Type,$Junk) = split("/",$Meta,2);
+        if ($Type == 'text') 
+        { $Format = 'flow'; }
+        else switch($Meta)
+        {
+          case "application/octet-string":
+          case "application/x-awk":
+          case "application/x-csh":
+          case "application/x-javascript":
+          case "application/x-perl":
+          case "application/x-shellscript":
+          case "application/x-rpm-spec":
+          case "application/xml":
+          case "message/rfc822":
+            $Format='flow';
+          break;
+          default:
+            $Format = 'flow';
 		}
+      }
 	  break;
 	}
 
-    /**********************************
-     Show optional text message.
-     **********************************/
-    if (!empty($ShowText)) { $V .= $ShowText; }
-
     /**********************************
       Display micro header
      **********************************/
@@ -663,21 +687,63 @@ class ui_view extends FO_Plugin
      ***********************************/
     print $V;
     $V = "";
+    $openedFin = False;
     if (empty($Fin))
       {
       $Fin = @fopen( RepPathItem($Item) ,"rb");
+      if ($Fin) $openedFin = true;
       if (empty($Fin))
 	{
-	print "File contents are not available in the repository.\n";
-	return;
+	  /* Added by vincent implement when view files which not in repository, ask user if want to reunpack*/
+	  /** BEGIN **/
+		/* If this is a POST, then process the request. */
+  	 $uploadunpack = GetParm('uploadunpack',PARM_INTEGER);
+     $uploadpk = $Upload;
+	   $flag = 0;
+
+	   $P = &$Plugins[plugin_find_id("ui_reunpack")];
+	   $state = $P->CheckStatus($uploadpk, "unpack", "unpack");
+	   //print "<p>$state</p>";
+	   if ( $state == 0 || $state == 2)
+	   {
+  	   if (!empty($uploadunpack))
+	     {
+    	   $rc = $P->AgentAdd($uploadpk);
+    	   if (empty($rc))
+  	       {
+  	         /* Need to refresh the screen */
+  	         $V .= displayMessage('Unpack added to job queue');
+  	         $flag = 1;
+  	                print "<p> <font color=red>Reunpack job is running: you can see it in <a href='" . Traceback_uri() . "?mod=showjobs'>jobqueue</a> </font></p>";
+  	       }
+  	       else
+  	       {
+  	         $V .= displayMessage("Unpack of Upload failed: $rc");
+	         }
+  	       print $V;
+	     }
+	   }     
+	   else {
+	     $flag = 1;
+       print "<p> <font color=red>Reunpack job is running: you can see it in <a href='" . Traceback_uri() . "?mod=showjobs'>jobqueue</a> </font></p>";
+     }
+	   print "File contents are not available in the repository.\n";
+	   $P = &$Plugins[plugin_find_id("ui_reunpack")];
+     print $P->ShowReunpackView($Item,$flag);
+	   return;
 	}
+	  /** END **/ 
       }
     rewind($Fin);
     $Pages = "";
     $Uri = preg_replace('/&page=[0-9]*/','',Traceback());
+    $HighlightMenu = "";
+
+    $HighlightMenu .= "</center>";  // some fcn left a dangling center
+
     if ($Format == 'hex')
 	{
-	$HighlightMenu = $this->GetHighlightMenu(VIEW_BLOCK_HEX);
+	$HighlightMenu .= $this->GetHighlightMenu(VIEW_BLOCK_HEX, $ViewOnly);
 	if (!empty($HighlightMenu)) { print "<center>$HighlightMenu</center><hr>\n"; }
 	$PageMenu = $this->GetFileJumpMenu($Fin,$Page,VIEW_BLOCK_HEX,$Uri);
 	$PageSize = VIEW_BLOCK_HEX * $Page;
@@ -687,7 +753,7 @@ class ui_view extends FO_Plugin
 	}
     else if ($Format == 'text')
 	{
-	$HighlightMenu = $this->GetHighlightMenu(VIEW_BLOCK_TEXT);
+	$HighlightMenu .= $this->GetHighlightMenu(VIEW_BLOCK_TEXT, $ViewOnly);
 	if (!empty($HighlightMenu)) { print "<center>$HighlightMenu</center><hr>\n"; }
 	$PageMenu = $this->GetFileJumpMenu($Fin,$Page,VIEW_BLOCK_TEXT,$Uri);
 	$PageSize = VIEW_BLOCK_TEXT * $Page;
@@ -697,15 +763,16 @@ class ui_view extends FO_Plugin
 	}
     else if ($Format == 'flow')
 	{
-	$HighlightMenu = $this->GetHighlightMenu(VIEW_BLOCK_TEXT);
+	$HighlightMenu .= $this->GetHighlightMenu(VIEW_BLOCK_TEXT, $ViewOnly);
 	if (!empty($HighlightMenu)) { print "<center>$HighlightMenu</center><hr>\n"; }
 	$PageMenu = $this->GetFileJumpMenu($Fin,$Page,VIEW_BLOCK_TEXT,$Uri);
 	$PageSize = VIEW_BLOCK_TEXT * $Page;
 	if (!empty($PageMenu)) { print "<center>$PageMenu</center><br>\n"; }
+    if (!empty($ShowText)) { echo $ShowText, "<hr>"; }
 	$this->ShowText($Fin,$PageSize,1,VIEW_BLOCK_TEXT);
 	if (!empty($PageMenu)) { print "<P /><center>$PageMenu</center><br>\n"; }
 	}
-    fclose($Fin);
+    if ($openedFin) fclose($Fin);
     return;
     } // ShowView()
 
@@ -721,7 +788,12 @@ class ui_view extends FO_Plugin
    ***********************************************************/
   function Output()
     {
+    global $DB, $PG_CONN;
+
     if ($this->State != PLUGIN_STATE_READY) { return; }
+
+    if (!$PG_CONN) { $dbok = $DB->db_init(); if (!$dbok) echo "NO DB connection"; }
+
     $V="";
     switch($this->OutputType)
       {
