@@ -49,7 +49,6 @@ define("PLUGIN_DB_DELETE",6);	/* record deletion permitted */
 define("PLUGIN_DB_DEBUG",7);	/* see and run debug code */
 define("PLUGIN_DB_USERADMIN",10);	/* add/delete users */
 
-error_reporting(E_NOTICE & E_STRICT);
 /*************************************************************
  This is the Plugin class.  All plugins should:
  1. Use this class or extend this class.
@@ -193,6 +192,7 @@ class FO_Plugin
     global $Plugins;
 
     if ($this->State != PLUGIN_STATE_INVALID) {
+      //print "<pre>TDB: returning state invalid\n</pre>";
       return(1); // don't re-run
     }
     if ($this->Name !== "") { // Name must be defined
@@ -337,6 +337,8 @@ class FO_Plugin
 
         $V .= "<html>\n";
         $V .= "<head>\n";
+        $V .= "<meta name='description' content='The study of Open Source'>\n";
+        $V .= "<meta http-equiv='Content-Type' content='text/html;charset=UTF-8'>\n";
         if ($this->NoHeader == 0)
         {
           /** Known bug: DOCTYPE "should" be in the HEADER
@@ -344,7 +346,7 @@ class FO_Plugin
            Also, IE will ignore <style>...</style> tags that are NOT
            in a <head>...</head> block.
            **/
-          if (!empty($Title)) { $V .= "<title>" . htmlentities($Title) . "</title>\n"; }
+          if (!empty($this->Title)) { $V .= "<title>" . htmlentities($this->Title) . "</title>\n"; }
           $V .= "<link rel='stylesheet' href='fossology.css'>\n";
           print $V; $V="";
           if (!empty($Menu)) { print $Menu->OutputCSS(); }
